@@ -1,5 +1,5 @@
 (* camlp4r pa_extend.cmo ../src/pa_lock.cmo *)
-(* $Id: ged2gwb.ml,v 4.31 2002/03/08 10:32:15 ddr Exp $ *)
+(* $Id: ged2gwb.ml,v 4.37 2002/11/14 11:09:05 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -35,8 +35,14 @@ type charset =
   | MacIntosh ]
 ;
 
+type case =
+  [ NoCase
+  | LowerCase
+  | UpperCase ]
+;
+
 value lowercase_first_names = ref False;
-value lowercase_surnames = ref False;
+value case_surnames = ref NoCase;
 value extract_first_names = ref False;
 value extract_public_names = ref True;
 value charset_option = ref None;
@@ -499,33 +505,18 @@ value date_value = Grammar.Entry.create date_g "date value";
 value date_interval = Grammar.Entry.create date_g "date interval";
 value date_value_recover = Grammar.Entry.create date_g "date value";
 
-value roman_int_decode s =
-  let decode_digit one five ten r =
-    loop 0 where rec loop cnt i =
-      if i >= String.length s then (10 * r + cnt, i)
-      else if s.[i] = one then loop (cnt + 1) (i + 1)
-      else if s.[i] = five then
-        if cnt = 0 then loop 5 (i + 1) else (10 * r + 5 - cnt, i + 1)
-      else if s.[i] = ten then (10 * r + 10 - cnt, i + 1)
-      else (10 * r + cnt, i)
-  in
-  let (r, i) = decode_digit 'M' 'M' 'M' 0 0 in
-  let (r, i) = decode_digit 'C' 'D' 'M' r i in
-  let (r, i) = decode_digit 'X' 'L' 'C' r i in
-  let (r, i) = decode_digit 'I' 'V' 'X' r i in
-  if i = String.length s then r else raise Not_found
-;
-
 value is_roman_int x =
   try
-    let _ = roman_int_decode x in
+    let _ = Gutil.arabian_of_roman x in
     True
   with
   [ Not_found -> False ]
 ;
 
 value roman_int =
-  let p = parser [: `("ID", x) when is_roman_int x :] -> roman_int_decode x in
+  let p =
+    parser [: `("ID", x) when is_roman_int x :] -> Gutil.arabian_of_roman x
+  in
   Grammar.Entry.of_parser date_g "roman int" p
 ;
 
@@ -621,8 +612,15 @@ EXTEND
           match dr with
           [ Begin (d, cal) -> Dgreg {(d) with prec = After} cal
           | End (d, cal) -> Dgreg {(d) with prec = Before} cal
-          | BeginEnd (d1, cal) (d2, _) ->
-              Dgreg {(d1) with prec = YearInt d2.year} cal ]
+          | BeginEnd (d1, cal1) (d2, cal2) ->
+              let y2 =
+                match cal2 with
+                [ Dgregorian -> d2.year
+                | Djulian -> (Calendar.julian_of_gregorian d2).year
+                | Dfrench -> (Calendar.french_of_gregorian d2).year
+                | Dhebrew -> (Calendar.hebrew_of_gregorian d2).year ]
+              in
+              Dgreg {(d1) with prec = YearInt y2} cal1 ]
       | (d, cal) = date -> Dgreg d cal
       | s = TEXT -> Dtext s ] ]
   ;
@@ -1378,6 +1376,13 @@ value rec build_remain_tags =
           rest] ]
 ;
 
+value applycase_surname s =
+  match case_surnames.val with
+  [ NoCase -> s
+  | LowerCase -> lowercase_name s
+  | UpperCase -> String.uppercase s ]
+;
+
 value add_indi gen r =
   let ip = per_index gen r.rval in
   let name_sons = find_field "NAME" r.rsons in
@@ -1456,7 +1461,7 @@ value add_indi gen r =
           List.fold_right (fun fa fal -> if fa = pn then fal else [fa :: fal])
             fal []
         in
-        let s = if lowercase_surnames.val then lowercase_name s else s in
+        let s = applycase_surname s in
         let r =
           let key = Name.strip_lower (nominative f ^ " " ^ nominative s) in
           try Hashtbl.find gen.g_hnam key with
@@ -1483,9 +1488,7 @@ value add_indi gen r =
             let list = purge_list (list_of_string r.rval) in
             List.fold_right
               (fun x list ->
-                 let x =
-                   if lowercase_surnames.val then lowercase_name x else x
-                 in
+                 let x = applycase_surname x in
                  if x <> surname then [x :: list] else list)
               list []
         | _ -> [] ]
@@ -1815,12 +1818,20 @@ value add_fam_norm gen r adop_list =
       match sons with
       [ Some r ->
           let (u, p) =
-            match find_field "PLAC" r.rsons with
-            [ Some r ->
+            match find_all_fields "PLAC" r.rsons with
+            [ [r :: rl] ->
                 if String.uncapitalize r.rval = "unmarried" then
                   (NotMarried, "")
-                else (relation, r.rval)
-            | _ -> (relation, "") ]
+                else
+                  let p = r.rval in
+                  loop rl where rec loop =
+                    fun
+                    [ [r :: rl] ->
+                        if String.uncapitalize r.rval = "unmarried" then
+                          (NotMarried, p)
+                        else loop rl
+                    | [] -> (relation, p) ]
+            | [] -> (relation, "") ]
           in
           let u =
             match find_field "TYPE" r.rsons with
@@ -1829,11 +1840,9 @@ value add_fam_norm gen r adop_list =
             | None -> u ]
           in
           let d =
-            if u = NotMarried then None
-            else
-              match find_field "DATE" r.rsons with
-              [ Some r -> date_of_field r.rpos r.rval
-              | _ -> None ]
+            match find_field "DATE" r.rsons with
+            [ Some r -> date_of_field r.rpos r.rval
+            | _ -> None ]
           in
           let rec heredis_witnesses =
             fun
@@ -2021,7 +2030,7 @@ value sort_by_date proj list =
     Sort.list
       (fun e1 e2 ->
          match (proj e1, proj e2) with
-         [ (Some d1, Some d2) -> not (strictement_apres d1 d2)
+         [ (Some d1, Some d2) -> not (strictly_after d1 d2)
          | _ -> False ])
       list
   else list
@@ -2033,24 +2042,24 @@ value print_base_error base =
   fun
   [ AlreadyDefined p ->
       fprintf log_oc.val "%s\nis defined several times\n"
-        (denomination base p)
+        (designation base p)
   | OwnAncestor p ->
       fprintf log_oc.val "%s\nis his/her own ancestor\n"
-        (denomination base p)
+        (designation base p)
   | BadSexOfMarriedPerson p ->
       fprintf log_oc.val "%s\n  bad sex for a married person\n"
-        (denomination base p) ]
+        (designation base p) ]
 ;
 
 value print_base_warning base =
   fun
   [ BirthAfterDeath p ->
       fprintf log_oc.val "%s\n  born after his/her death\n"
-        (denomination base p)
+        (designation base p)
   | IncoherentSex p fixed not_fixed ->
       do {
         fprintf log_oc.val "%s\n  sex not coherent with relations"
-          (denomination base p);
+          (designation base p);
         if fixed > 0 then
           if not_fixed > 0 then
             fprintf log_oc.val " (fixed in %d of the %d cases)"
@@ -2063,56 +2072,56 @@ value print_base_warning base =
   | ChangedOrderOfChildren ifam des _ ->
       let cpl = coi base ifam in
       fprintf log_oc.val "Changed order of children of %s and %s\n"
-        (denomination base (poi base cpl.father))
-        (denomination base (poi base cpl.mother))
+        (designation base (poi base cpl.father))
+        (designation base (poi base cpl.mother))
   | ChildrenNotInOrder ifam des elder x ->
       let cpl = coi base ifam in
       do {
         fprintf log_oc.val
           "The following children of\n  %s\nand\n  %s\nare not in order:\n"
-          (denomination base (poi base cpl.father))
-          (denomination base (poi base cpl.mother));
-        fprintf log_oc.val "- %s\n" (denomination base elder);
-        fprintf log_oc.val "- %s\n" (denomination base x)
+          (designation base (poi base cpl.father))
+          (designation base (poi base cpl.mother));
+        fprintf log_oc.val "- %s\n" (designation base elder);
+        fprintf log_oc.val "- %s\n" (designation base x)
       }
   | DeadTooEarlyToBeFather father child ->
       do {
-        fprintf log_oc.val "%s\n" (denomination base child);
+        fprintf log_oc.val "%s\n" (designation base child);
         fprintf log_oc.val
           "  is born more than 2 years after the death of his/her father\n";
-        fprintf log_oc.val "%s\n" (denomination base father)
+        fprintf log_oc.val "%s\n" (designation base father)
       }
   | MarriageDateAfterDeath p ->
       do {
-        fprintf log_oc.val "%s\n" (denomination base p);
+        fprintf log_oc.val "%s\n" (designation base p);
         fprintf log_oc.val "married after his/her death\n"
       }
   | MarriageDateBeforeBirth p ->
       do {
-        fprintf log_oc.val "%s\n" (denomination base p);
+        fprintf log_oc.val "%s\n" (designation base p);
         fprintf log_oc.val "married before his/her birth\n"
       }
   | MotherDeadAfterChildBirth mother child ->
       fprintf log_oc.val
         "%s\n  is born after the death of his/her mother\n%s\n"
-        (denomination base child) (denomination base mother)
+        (designation base child) (designation base mother)
   | ParentBornAfterChild parent child ->
       fprintf log_oc.val "%s born after his/her child %s\n"
-        (denomination base parent) (denomination base child)
+        (designation base parent) (designation base child)
   | ParentTooYoung p a ->
       fprintf log_oc.val "%s was parent at age of %d\n"
-        (denomination base p) (annee a)
+        (designation base p) (year_of a)
   | TitleDatesError p t ->
       do {
-        fprintf log_oc.val "%s\n" (denomination base p);
+        fprintf log_oc.val "%s\n" (designation base p);
         fprintf log_oc.val "has incorrect title dates as:\n";
         fprintf log_oc.val "  %s %s\n" (sou base t.t_ident)
           (sou base t.t_place)
       }
   | UndefinedSex _ -> ()
   | YoungForMarriage p a ->
-      fprintf log_oc.val "%s married at age %d\n" (denomination base p)
-        (annee a) ]
+      fprintf log_oc.val "%s married at age %d\n" (designation base p)
+        (year_of a) ]
 ;
 
 value find_lev0 =
@@ -2409,11 +2418,11 @@ value check_parents_children base =
               let p = base.data.persons.get i in
               fprintf log_oc.val
                 "%s is not the child of his/her parents\n"
-                (denomination base p);
+                (designation base p);
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.father));
+                (designation base (poi base cpl.father));
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.mother));
+                (designation base (poi base cpl.mother));
               fprintf log_oc.val "=> no more parents for him/her\n";
               fprintf log_oc.val "\n";
               flush log_oc.val;
@@ -2429,11 +2438,11 @@ value check_parents_children base =
         then do {
           fprintf log_oc.val
             "%s is spouse in this family but neither husband nor wife:\n"
-            (denomination base (base.data.persons.get i));
+            (designation base (base.data.persons.get i));
           fprintf log_oc.val "- %s\n"
-            (denomination base (poi base cpl.father));
+            (designation base (poi base cpl.father));
           fprintf log_oc.val "- %s\n"
-            (denomination base (poi base cpl.mother));
+            (designation base (poi base cpl.mother));
           let fath = poi base cpl.father in
           let moth = poi base cpl.mother in
           let ffn = sou base fath.first_name in
@@ -2484,11 +2493,11 @@ value check_parents_children base =
         [ Some ifam ->
             if Adef.int_of_ifam ifam <> i then do {
               fprintf log_oc.val "Other parents for %s\n"
-                (denomination base p);
+                (designation base p);
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.father));
+                (designation base (poi base cpl.father));
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.mother));
+                (designation base (poi base cpl.mother));
               fprintf log_oc.val "=> deleted in this family\n";
               fprintf log_oc.val "\n";
               flush log_oc.val;
@@ -2499,11 +2508,11 @@ value check_parents_children base =
             do {
               fprintf log_oc.val
                 "%s has no parents but is the child of\n"
-                (denomination base p);
+                (designation base p);
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.father));
+                (designation base (poi base cpl.father));
               fprintf log_oc.val "- %s\n"
-                (denomination base (poi base cpl.mother));
+                (designation base (poi base cpl.mother));
               fprintf log_oc.val "=> added parents\n";
               fprintf log_oc.val "\n";
               flush log_oc.val;
@@ -2568,11 +2577,11 @@ value check_parents_sex base =
     else if fath.sex = Female || moth.sex = Male then do {
       if fath.sex = Female then
         fprintf log_oc.val "Warning - husband with female sex: %s\n"
-          (denomination base fath)
+          (designation base fath)
       else ();
       if moth.sex = Male then
         fprintf log_oc.val "Warning - wife with male sex: %s\n"
-          (denomination base moth)
+          (designation base moth)
       else ();
       flush log_oc.val;
       fam.relation := NoSexesCheck
@@ -2635,7 +2644,7 @@ value negative_dates base =
     let p = base.data.persons.get i in
     match (Adef.od_of_codate p.birth, date_of_death p.death) with
     [ (Some (Dgreg d1 _), Some (Dgreg d2 _)) ->
-        if annee d1 > 0 && annee d2 > 0 && strictement_avant_dmy d2 d1 then
+        if year_of d1 > 0 && year_of d2 > 0 && strictly_before_dmy d2 d1 then
           negative_date_ancestors base (base.data.persons.get i)
         else ()
     | _ -> () ]
@@ -2752,10 +2761,13 @@ value speclist =
 - Lowercase first names -
        Convert first names to lowercase letters, with initials in
        uppercase.");
-   ("-ls", Arg.Set lowercase_surnames, "   \
+   ("-ls", Arg.Unit (fun () -> case_surnames.val := LowerCase), "   \
 - Lowercase surnames -
        Convert surnames to lowercase letters, with initials in
        uppercase. Try to keep lowercase particles.");
+   ("-us", Arg.Unit (fun () -> case_surnames.val := UpperCase), "   \
+- Uppercase surnames -
+       Convert surnames to uppercase letters.");
    ("-fne",
     Arg.String
       (fun s ->
