@@ -1,12 +1,11 @@
 (* camlp4r *)
-(* $Id: setup.ml,v 4.35 2002/03/06 04:08:48 ddr Exp $ *)
+(* $Id: setup.ml,v 4.42 2002/11/14 16:54:29 ddr Exp $ *)
 
 open Printf;
 
 value port = ref 2316;
 value default_lang = ref "en";
 value setup_dir = ref ".";
-value charset = "iso-8859-1";
 value lang_param = ref "";
 
 value slashify s =
@@ -78,15 +77,25 @@ type config =
   { lang : string;
     comm : string;
     env : list (string * string);
-    request : list string }
+    request : list string;
+    lexicon : Hashtbl.t string string }
+;
+
+value transl conf w =
+  try Hashtbl.find conf.lexicon w with [ Not_found -> "[" ^ w ^ "]" ]
+;
+
+value charset conf =
+  try Hashtbl.find conf.lexicon " !charset" with
+  [ Not_found -> "iso-8859-1" ]
 ;
 
 value nl () = Wserver.wprint "\013\010";
 
-value header_no_page_title title =
+value header_no_page_title conf title =
   do {
     Wserver.http "";
-    Wserver.wprint "Content-type: text/html; charset=%s" charset;
+    Wserver.wprint "Content-type: text/html; charset=%s" (charset conf);
     nl (); nl ();
     Wserver.wprint "\
 <!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\" \
@@ -126,12 +135,12 @@ GeneWeb %s</em></font>" Version.txt;
   }
 ;
 
-value header title =
+value header conf title =
   do {
-    header_no_page_title title;
+    header_no_page_title conf title;
     Wserver.wprint "<h1>";
     title False;
-    Wserver.wprint "</h1>\n"
+    Wserver.wprint "</h1>\n";
   }
 ;
 
@@ -322,7 +331,7 @@ value macro conf =
   | 'u' -> Filename.dirname (abs_setup_dir ())
   | 'x' -> setup_dir.val
   | 'w' -> slashify (Sys.getcwd ())
-  | '$' -> "$"
+  | '%' -> "%"
   | c -> "BAD MACRO " ^ String.make 1 c ]
 ;
 
@@ -348,7 +357,7 @@ value variables bname =
   let (vlist, flist) =
     loop ([], []) where rec loop (vlist, flist) =
       match strm with parser
-      [ [: `'$' :] ->
+      [ [: `'%' :] ->
           let (vlist, flist) =
             match strm with parser
             [ [: `('E' | 'C') :] ->
@@ -375,6 +384,29 @@ value variables bname =
   }
 ;
 
+value nth_field s n =
+  loop 0 0 where rec loop nth i =
+    let j =
+      try String.index_from s i '/' with [ Not_found -> String.length s ]
+    in
+    if nth = n then String.sub s i (j - i)
+    else if j = String.length s then s
+    else loop (nth + 1) (j + 1)
+;
+
+value translate_phrase lang lexicon s n =
+  let n =
+    match n with
+    [ Some n -> n
+    | None -> 0 ]
+  in
+  try
+    let s = Hashtbl.find lexicon s in
+    nth_field s n
+  with
+  [ Not_found -> "[" ^ nth_field s n ^ "]" ]
+;
+
 value rec copy_from_stream conf print strm =
   try
     while True do {
@@ -383,10 +415,22 @@ value rec copy_from_stream conf print strm =
           match Stream.peek strm with
           [ Some '\n' ->
               let s = parse_upto ']' strm in
-              print (Translate.inline conf.lang '$' (macro conf) s)
+              print (Translate.inline conf.lang '%' (macro conf) s)
           | _ ->
-              print "[" ]
-      | '$' ->
+              let s =
+                loop 0 where rec loop len =
+                  match strm with parser
+                  [ [: `']' :] -> Buff.get len
+                  | [: `c :] -> loop (Buff.store len c)
+                  | [: :] -> Buff.get len ]
+              in
+              let n =
+                match strm with parser
+                [ [: `('0'..'9' as c) :] -> Some (Char.code c - Char.code '0')
+                | [: :] -> None ]
+              in
+              print (translate_phrase conf.lang conf.lexicon s n) ]
+      | '%' ->
           let c = Stream.next strm in
           match c with
           [ 'b' -> for_all conf print (all_db ".") strm
@@ -441,6 +485,10 @@ value rec copy_from_stream conf print strm =
                         print (if c = 'C' then " checked" else " selected")
                       else ()
                   | None -> () ]
+              | 'L' ->
+                  let lang = get_variable strm in
+                  let lang_def = transl conf " !languages" in
+                  print (Translate.language_name lang lang_def)
               | 'V' | 'F' ->
                   let k = get_variable strm in
                   match p_getenv conf.env k with
@@ -617,7 +665,7 @@ value print_file conf bname =
   [ Some ic ->
       do {
         Wserver.http "";
-        Wserver.wprint "Content-type: text/html; charset=%s" charset;
+        Wserver.wprint "Content-type: text/html; charset=%s" (charset conf);
         nl (); nl ();
         copy_from_stream conf (fun x -> Wserver.wprint "%s" x)
           (Stream.of_channel ic);
@@ -627,7 +675,7 @@ value print_file conf bname =
   | None ->
       let title _ = Wserver.wprint "Error" in
       do {
-        header title;
+        header conf title;
         Wserver.wprint "<ul><li>\n";
         Wserver.wprint "Cannot access file \"%s\".\n" fname;
         Wserver.wprint "</ul>\n";
@@ -638,7 +686,7 @@ value print_file conf bname =
 
 value error conf str =
   do {
-    header (fun _ -> Wserver.wprint "Incorrect request");
+    header conf (fun _ -> Wserver.wprint "Incorrect request");
     Wserver.wprint "<em>%s</em>\n" (String.capitalize str);
     trailer conf
   }
@@ -678,9 +726,18 @@ value out_name_of_gw in_file =
   else f
 ;
 
+value basename s =
+  loop (String.length s - 1) where rec loop i =
+    if i < 0 then s
+    else
+      match s.[i] with
+      [ 'a'..'z' | 'A'..'Z' | '0'..'9' | '_' | '.' -> loop (i - 1)
+      | _ -> String.sub s (i + 1) (String.length s - i - 1) ]
+;
+
 value setup_gen conf =
   match p_getenv conf.env "v" with
-  [ Some fname -> print_file conf fname
+  [ Some fname -> print_file conf (basename fname)
   | _ -> error conf "request needs \"v\" parameter" ]
 ;
 
@@ -709,7 +766,7 @@ value simple conf =
   let conf =
     {comm = if ged = "" then "gwc" else "ged2gwb";
      env = list_replace "o" out_file env; lang = conf.lang;
-     request = conf.request}
+     request = conf.request; lexicon = conf.lexicon}
   in
   if ged <> "" && not (Sys.file_exists ged) then
     print_file conf "err_unkn.htm"
@@ -1466,6 +1523,69 @@ value only_addr () =
   | None -> local_addr ]
 ;
 
+value lindex s c =
+  pos 0 where rec pos i =
+    if i == String.length s then None
+    else if s.[i] == c then Some i
+    else pos (i + 1)
+;
+
+value input_lexicon lang =
+  let t = Hashtbl.create 501 in
+  try
+    let ic =
+      open_in
+        (List.fold_right Filename.concat [setup_dir.val; "setup"; "lang"]
+           "lexicon.txt")
+    in
+    let derived_lang =
+      match lindex lang '-' with
+      [ Some i -> String.sub lang 0 i
+      | _ -> "" ]
+    in
+    try
+      do {
+        try
+          while True do {
+            let k =
+              find_key (input_line ic) where rec find_key line =
+                if String.length line < 4 then find_key (input_line ic)
+                else if String.sub line 0 4 <> "    " then
+                  find_key (input_line ic)
+                else line
+            in
+            let k = String.sub k 4 (String.length k - 4) in
+            let rec loop line =
+              match lindex line ':' with
+              [ Some i ->
+                  let line_lang = String.sub line 0 i in
+                  do {
+                    if line_lang = lang ||
+                       line_lang = derived_lang && not (Hashtbl.mem t k) then
+                      let v =
+                        if i + 1 = String.length line then ""
+                        else
+                          String.sub line (i + 2) (String.length line - i - 2)
+                      in
+                      Hashtbl.add t k v
+                    else ();
+                    loop (input_line ic)
+                  }
+              | None -> () ]
+            in
+            loop (input_line ic)
+          }
+        with
+        [ End_of_file -> () ];
+        close_in ic;
+        t
+      }
+    with e ->
+      do { close_in ic; raise e }
+  with
+  [ Sys_error _ -> t ]
+;
+
 value setup (addr, req) comm env_str =
   let conf =
     let env = create_env env_str in
@@ -1473,14 +1593,16 @@ value setup (addr, req) comm env_str =
       let lang =
         if comm = "" then default_lang.val else String.lowercase comm
       in
-      {lang = lang; comm = ""; env = env; request = req}
+      let lexicon = input_lexicon lang in
+      {lang = lang; comm = ""; env = env; request = req; lexicon = lexicon}
     else
       let (lang, env) =
         match p_getenv env "lang" with
         [ Some x -> (x, list_remove_assoc "lang" env)
         | _ -> (default_lang.val, env) ]
       in
-      {lang = lang; comm = comm; env = env; request = req}
+      let lexicon = input_lexicon lang in
+      {lang = lang; comm = comm; env = env; request = req; lexicon = lexicon}
   in
   let saddr = string_of_sockaddr addr in
   let s = only_addr () in
@@ -1514,7 +1636,10 @@ value copy_text lang fname =
   let fname = Filename.concat dir fname in
   match try Some (open_in fname) with [ Sys_error _ -> None ] with
   [ Some ic ->
-      let conf = {lang = lang; comm = ""; env = []; request = []} in
+      let conf =
+        {lang = lang; comm = ""; env = []; request = [];
+         lexicon = Hashtbl.create 1}
+      in
       do {
         copy_from_stream conf print_string (Stream.of_channel ic);
         flush stdout;
@@ -1580,7 +1705,7 @@ value null_reopen flags fd =
   else ()
 ;
 
-value setup_available_languages = ["de"; "en"; "es"; "fr"; "lv"; "sv"];
+value setup_available_languages = ["de"; "en"; "es"; "fr"; "it"; "lv"; "sv"];
 
 value intro () =
   let (default_gwd_lang, default_setup_lang) =
