@@ -1,6 +1,6 @@
 (* camlp4r ./def.syn.cmo ./pa_html.cmo *)
-(* $Id: ascend.ml,v 4.16 2002/03/06 12:21:17 ddr Exp $ *)
-(* Copyright (c) 2001 INRIA *)
+(* $Id: ascend.ml,v 4.28 2002/12/26 14:26:18 ddr Exp $ *)
+(* Copyright (c) 2002 INRIA *)
 
 open Config;
 open Def;
@@ -19,20 +19,20 @@ value limit_by_tree conf =
   | None -> 7 ]
 ;
 
-value niveau_max_ascendance conf base ip =
+value max_ancestor_level conf base ip =
   let _ = base.data.ascends.array () in
   let _ = base.data.couples.array () in
   let x = ref 0 in
   let mark = Array.create base.data.persons.len False in
-  let rec loop niveau ip =
+  let rec loop level ip =
     if mark.(Adef.int_of_iper ip) then ()
     else do {
       mark.(Adef.int_of_iper ip) := True;
-      x.val := max x.val niveau;
+      x.val := max x.val level;
       match (aget conf base ip).parents with
       [ Some ifam ->
           let cpl = coi base ifam in
-          do { loop (succ niveau) cpl.father; loop (succ niveau) cpl.mother }
+          do { loop (succ level) cpl.father; loop (succ level) cpl.mother }
       | _ -> () ]
     }
   in
@@ -63,7 +63,7 @@ value text_level conf =
         (transl_nth conf "nth (generation)" i) ]
 ;
 
-value print_choice conf base p niveau_effectif =
+value print_choice conf base p effective_level =
   tag "form" "method=get action=\"%s\"" conf.command begin
     Util.hidden_env conf;
     Wserver.wprint "\n";
@@ -71,16 +71,16 @@ value print_choice conf base p niveau_effectif =
     wprint_hidden_person conf base "" p;
     tag "center" begin
       tag "select" "name=v" begin
-        let rec boucle i =
-          if i > niveau_effectif + 1 then ()
+        let rec loop i =
+          if i > effective_level + 1 then ()
           else do {
             Wserver.wprint "  <option value=%d%s> %s\n" i
               (if i == 0 then " selected" else "")
               (capitale (text_to conf i));
-            boucle (succ i)
+            loop (succ i)
           }
         in
-        boucle 1;
+        loop 1;
       end;
       Wserver.wprint "<input type=submit value=\"Ok\">\n";
     end;
@@ -102,7 +102,7 @@ value print_choice conf base p niveau_effectif =
           Wserver.wprint "<input type=radio name=t value=T> %s\n"
             (capitale (transl conf "tree"));
           let limit = limit_by_tree conf in
-          if niveau_effectif < limit then ()
+          if effective_level < limit then ()
           else
             Wserver.wprint "(%s %d %s)\n" (transl conf "maximum") limit
               (transl_nth conf "generation/generations" 1);
@@ -120,7 +120,7 @@ value print_choice conf base p niveau_effectif =
         tag "td valign=top" begin
           Wserver.wprint "<input type=radio name=t value=L> %s\n"
             (capitale (transl_nth conf "list/list (ancestors)" 1));
-          if niveau_effectif < limit_by_list conf then ()
+          if effective_level < limit_by_list conf then ()
           else
             Wserver.wprint "(%s %d %s)\n" (transl conf "maximum")
               (limit_by_list conf)
@@ -128,7 +128,7 @@ value print_choice conf base p niveau_effectif =
           Wserver.wprint "<br>\n";
           Wserver.wprint "<input type=radio name=t value=H> %s\n"
             (capitale (transl conf "horizontally"));
-          if niveau_effectif < limit_by_list conf then ()
+          if effective_level < limit_by_list conf then ()
           else
             Wserver.wprint "(%s %d %s)\n" (transl conf "maximum")
               (limit_by_list conf)
@@ -168,19 +168,20 @@ value print_choice conf base p niveau_effectif =
   end
 ;
 
-value afficher_menu_ascendants conf base p =
-  let niveau_effectif = niveau_max_ascendance conf base p.cle_index in
+value display_ancestor_menu conf base p =
+  let effective_level = max_ancestor_level conf base p.cle_index in
   let title h =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (capitale (transl conf "ancestors"))
+         (transl_a_of_b conf
+            (capitale (transl conf "ancestors"))
             (txt_fun raw_access conf base p)))
   in
   do {
     header conf title;
     tag "center" begin
-      print_choice conf base p niveau_effectif;
+      print_choice conf base p effective_level;
       html_p conf;
       Wserver.wprint
         (fcapitale (ftransl conf "navigation with %t as Sosa reference"))
@@ -202,39 +203,39 @@ value afficher_menu_ascendants conf base p =
   }
 ;
 
-value afficher_ancetre conf base p =
+value display_ancestor conf base p =
   do {
-    afficher_personne_referencee conf base p;
-    Date.afficher_dates_courtes conf base p
+    Wserver.wprint "\n%s" (referenced_person_text conf base p);
+    Wserver.wprint "%s" (Date.short_dates_text conf base p)
   }
 ;
 
-value afficher_ascendants_jusqu_a conf base niveau_max p =
-  let niveau_max = min (limit_by_list conf) niveau_max in
-  let rec boucle niveau ip =
-    if niveau < niveau_max then
+value display_ancestors_upto conf base max_level p =
+  let max_level = min (limit_by_list conf) max_level in
+  let rec loop level ip =
+    if level < max_level then
       let x = aget conf base ip in
       match x.parents with
       [ Some ifam ->
           let cpl = coi base ifam in
           let pere = pget conf base cpl.father in
           let mere = pget conf base cpl.mother in
-          let know_fath = connais base pere in
-          let know_moth = connais base mere in
+          let know_fath = know base pere in
+          let know_moth = know base mere in
           if know_fath || know_moth then
             tag "ul" begin
               if know_fath then do {
                 Wserver.wprint "<li type=square> ";
-                afficher_ancetre conf base pere;
+                display_ancestor conf base pere;
                 Wserver.wprint "\n";
-                boucle (succ niveau) cpl.father
+                loop (succ level) cpl.father
               }
               else ();
               if know_moth then do {
                 Wserver.wprint "<li type=circle> ";
-                afficher_ancetre conf base mere;
+                display_ancestor conf base mere;
                 Wserver.wprint "\n";
-                boucle (succ niveau) cpl.mother
+                loop (succ level) cpl.mother
               }
               else ();
             end
@@ -246,19 +247,13 @@ value afficher_ascendants_jusqu_a conf base niveau_max p =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+         (transl_a_of_b conf (transl conf "ancestors")
             (txt_fun raw_access conf base p)))
   in
   do {
     header conf title;
-(*
-    tag "nobr" begin
-*)
-      Wserver.wprint "%s.\n" (capitale (text_to conf niveau_max));
-      boucle 1 p.cle_index;
-(*
-    end;
-*)
+    Wserver.wprint "%s.\n" (capitale (text_to conf max_level));
+    loop 1 p.cle_index;
     trailer conf
   }
 ;
@@ -327,8 +322,8 @@ value print_generation_person conf base cnt gp =
         html_li conf;
         Num.print wpr (transl conf "(thousand separator)") n;
         Wserver.wprint " -\n";
-        afficher_personne_titre_referencee conf base p;
-        Date.afficher_dates_courtes conf base p;
+        Wserver.wprint "%s" (referenced_person_title_text conf base p);
+        Wserver.wprint "%s" (Date.short_dates_text conf base p);
         Wserver.wprint "\n";
         incr cnt
       }
@@ -379,19 +374,19 @@ value will_print =
   | _ -> False ]
 ;
 
-value afficher_ascendants_numerotation conf base niveau_max p =
+value display_ancestors_with_numbers conf base max_level p =
   let mark = Array.create base.data.persons.len Num.zero in
   let cnt = ref 0 in
-  let rec generation niveau gpl =
-    if niveau <= niveau_max then do {
+  let rec generation level gpl =
+    if level <= max_level then do {
       html_li conf;
       Wserver.wprint "%s %d\n"
-        (capitale (transl_nth conf "generation/generations" 0)) niveau;
+        (capitale (transl_nth conf "generation/generations" 0)) level;
       tag "ul" begin
         List.iter (print_generation_person conf base cnt) gpl;
       end;
       let gpl = next_generation conf base mark gpl in
-      if List.exists will_print gpl then generation (niveau + 1) gpl else ()
+      if List.exists will_print gpl then generation (level + 1) gpl else ()
     }
     else ()
   in
@@ -399,13 +394,13 @@ value afficher_ascendants_numerotation conf base niveau_max p =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+         (transl_a_of_b conf (transl conf "ancestors")
             (txt_fun raw_access conf base p)))
   in
   do {
     header conf title;
     print_link_to_welcome conf True;
-    Wserver.wprint "%s.\n" (capitale (text_to conf niveau_max));
+    Wserver.wprint "%s.\n" (capitale (text_to conf max_level));
     tag "ul" begin
       mark.(Adef.int_of_iper p.cle_index) := Num.one;
       generation 1 [GP_person Num.one p.cle_index None];
@@ -441,9 +436,8 @@ value print_person_long_info conf base auth link p =
     if link = None && List.length p.titles > 0 &&
        (p.access <> Private || conf.friend || conf.wizard) then
        do {
-      Wserver.wprint ", <em>";
-      Perso.print_titles conf base False (transl_nth conf "and" 0) p;
-      Wserver.wprint "</em>"
+      Wserver.wprint ", <em>%s</em>"
+        (Perso.string_of_titles conf base False (transl_nth conf "and" 0) p)
     }
     else ();
     if auth then Date.print_dates conf base p else ();
@@ -509,7 +503,7 @@ value print_persons_parents conf base all_gp p =
            | None -> "" ])
       in
       Wserver.wprint ", %s\n"
-        (transl_decline2 conf "%1 of (same or greater generation level) %2"
+        (transl_a_of_gr_eq_gen_lev conf
            (transl_nth conf "son/daughter/child" (index_of_sex p.sex))
            (string cpl.father ^ "\n" ^ transl_nth conf "and" 0 ^ "\n" ^
               string cpl.mother))
@@ -521,7 +515,7 @@ value print_marriage_long conf base all_gp auth marr_nb p ifam =
   let ispouse = spouse p.cle_index (coi base ifam) in
   let spouse = pget conf base ispouse in
   let divorce = fam.divorce in
-  let auth = auth && age_autorise conf base spouse in
+  let auth = auth && authorized_age conf base spouse in
   do {
     Wserver.wprint (fcapitale (relation_txt conf p.sex fam))
       (fun _ ->
@@ -529,7 +523,9 @@ value print_marriage_long conf base all_gp auth marr_nb p ifam =
            match marr_nb with
            [ Some n -> Wserver.wprint " (%d)" n
            | None -> () ];
-           if auth then Perso.print_marriage_text conf base False fam else ()
+           if auth then
+             Wserver.wprint "%s" (Perso.string_of_marriage_text conf base fam)
+           else ()
          });
     Wserver.wprint "\n";
     stag "strong" begin
@@ -570,7 +566,7 @@ value has_notes conf base =
     (fun
      [ GP_person _ ip _ ->
          let p = pget conf base ip in
-         age_autorise conf base p && person_has_notes conf base p
+         authorized_age conf base p && person_has_notes conf base p
      | _ -> False ])
 ;
 
@@ -586,7 +582,7 @@ value print_other_marriages conf base ws all_gp auth ifamo p u =
 ;
 
 value print_notes_ref conf base p wn n child_n =
-  if wn && age_autorise conf base p && person_has_notes conf base p then do {
+  if wn && authorized_age conf base p && person_has_notes conf base p then do {
     Wserver.wprint "[%s " (capitale (transl_nth conf "note/notes" 0));
     stag "strong" begin
       stag "a" "href=\"#notes-%s%s\"" (Num.to_string n) child_n begin
@@ -603,8 +599,8 @@ value print_family_long conf base ws wn all_gp ifam nth moth_nb =
   let cpl = coi base ifam in
   let des = doi base ifam in
   let auth =
-    age_autorise conf base (pget conf base cpl.father) &&
-    age_autorise conf base (pget conf base cpl.mother)
+    authorized_age conf base (pget conf base cpl.father) &&
+    authorized_age conf base (pget conf base cpl.mother)
   in
   do {
     Wserver.wprint "<p>\n... ";
@@ -619,7 +615,7 @@ value print_family_long conf base ws wn all_gp ifam nth moth_nb =
     | None -> () ];
     Wserver.wprint ":\n<p>\n";
     let auth =
-      List.for_all (fun ip -> age_autorise conf base (pget conf base ip))
+      List.for_all (fun ip -> authorized_age conf base (pget conf base ip))
         (Array.to_list des.children)
     in
     tag "ol" "type=a" begin
@@ -632,8 +628,9 @@ value print_family_long conf base ws wn all_gp ifam nth moth_nb =
           Wserver.wprint "<li>\n";
           stag "strong" begin
             if pc.surname = (pget conf base cpl.father).surname then
-              afficher_prenom_de_personne_referencee conf base pc
-            else afficher_personne_referencee conf base pc;
+              Wserver.wprint "%s"
+                (referenced_person_text_without_surname conf base pc)
+            else Wserver.wprint "\n%s" (referenced_person_text conf base pc);
           end;
           print_person_long_info conf base auth n pc;
           Wserver.wprint ".\n";
@@ -691,13 +688,15 @@ value print_generation_person_long conf base ws wn all_gp last_gen gp =
               let fam = foi base ifam in
               let cpl = coi base ifam in
               let auth =
-                age_autorise conf base (pget conf base cpl.father) &&
-                age_autorise conf base (pget conf base cpl.mother)
+                authorized_age conf base (pget conf base cpl.father) &&
+                authorized_age conf base (pget conf base cpl.mother)
               in
               Wserver.wprint "... ";
               Wserver.wprint (relation_txt conf Male fam)
                 (fun _ ->
-                   if auth then Perso.print_marriage_text conf base False fam
+                   if auth then
+                     Wserver.wprint "%s"
+                       (Perso.string_of_marriage_text conf base fam)
                    else ());
               Wserver.wprint "...\n<p>\n"
             }
@@ -709,8 +708,10 @@ value print_generation_person_long conf base ws wn all_gp last_gen gp =
           end;
         end;
         Wserver.wprint ":\n";
-        stag "strong" begin afficher_personne_referencee conf base p; end;
-        print_person_long_info conf base (age_autorise conf base p) None p;
+        stag "strong" begin
+          Wserver.wprint "\n%s" (referenced_person_text conf base p);
+        end;
+        print_person_long_info conf base (authorized_age conf base p) None p;
         Wserver.wprint ".\n";
         match (aget conf base ip).parents with
         [ Some ifam ->
@@ -735,7 +736,7 @@ value print_generation_person_long conf base ws wn all_gp last_gen gp =
             | _ -> () ]
         | None -> () ];
         print_notes_ref conf base p wn n "";
-        print_other_marriages conf base ws all_gp (age_autorise conf base p)
+        print_other_marriages conf base ws all_gp (authorized_age conf base p)
           ifamo p u;
         match ifamo with
         [ Some ifam ->
@@ -776,16 +777,15 @@ value print_not_empty_src conf base new_parag first txt isrc =
     html_br conf;
     Wserver.wprint "-\n";
     first.val := False;
-    Wserver.wprint "<font size=-1><em>%s: " (txt ());
-    copy_string_with_macros conf [] src;
-    Wserver.wprint "</em></font>\n"
+    Wserver.wprint "<font size=-1><em>%s: %s</em></font>\n" (txt ())
+      (string_with_macros conf False [] src);
   }
 ;
 
 value print_sources conf base new_parag p =
   let u = uget conf base p.cle_index in
   let first = ref True in
-  let auth = age_autorise conf base p in
+  let auth = authorized_age conf base p in
   do {
     print_not_empty_src conf base new_parag first
       (fun () -> nominative (transl_nth conf "person/persons" 0)) p.psources;
@@ -821,7 +821,7 @@ value print_sources conf base new_parag p =
 ;
 
 value print_notes_for_someone conf base p n child_n =
-  if age_autorise conf base p && person_has_notes conf base p then do {
+  if authorized_age conf base p && person_has_notes conf base p then do {
     let notes = sou base p.notes in
     Wserver.wprint "<dt>\n";
     stag "strong" begin
@@ -833,7 +833,7 @@ value print_notes_for_someone conf base p n child_n =
       end;
     end;
     Wserver.wprint ": \n<dd>\n";
-    copy_string_with_macros conf [] notes;
+    Wserver.wprint "%s" (string_with_macros conf False [] notes);
     print_sources conf base (notes <> "") p;
     Wserver.wprint "<p>\n"
   }
@@ -890,27 +890,27 @@ value print_notes conf base all_gp ws =
   | _ -> () ]
 ;
 
-value afficher_ascendants_numerotation_long conf base niveau_max ws wn p =
+value display_ancestors_with_numbers_long conf base max_level ws wn p =
   let only = p_getenv conf.env "only" = Some "on" in
   let mark = Array.create base.data.persons.len Num.zero in
-  let rec get_generations niveau gpll gpl =
+  let rec get_generations level gpll gpl =
     let gpll = [gpl :: gpll] in
-    if niveau < niveau_max then
+    if level < max_level then
       let next_gpl = next_generation conf base mark gpl in
       if List.exists will_print next_gpl then
-        get_generations (niveau + 1) gpll next_gpl
+        get_generations (level + 1) gpll next_gpl
       else gpll
     else gpll
   in
-  let rec generation niveau all_gp =
+  let rec generation level all_gp =
     fun
     [ [gpl :: gpll] ->
         do {
-          if not only || niveau = niveau_max then do {
+          if not only || level = max_level then do {
             tag "h3" begin
               Wserver.wprint "<em>%s %d</em>\n"
                 (capitale (transl_nth conf "generation/generations" 0))
-                niveau;
+                level;
             end;
             List.iter
               (print_generation_person_long conf base ws wn all_gp
@@ -920,7 +920,7 @@ value afficher_ascendants_numerotation_long conf base niveau_max ws wn p =
             html_br conf
           }
           else ();
-          generation (niveau + 1) all_gp gpll
+          generation (level + 1) all_gp gpll
         }
     | [] -> () ]
   in
@@ -928,13 +928,13 @@ value afficher_ascendants_numerotation_long conf base niveau_max ws wn p =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+         (transl_a_of_b conf (transl conf "ancestors")
             (txt_fun raw_access conf base p)))
   in
   do {
     header conf title;
     if only then ()
-    else Wserver.wprint "%s.\n" (capitale (text_to conf niveau_max));
+    else Wserver.wprint "%s.\n" (capitale (text_to conf max_level));
     mark.(Adef.int_of_iper p.cle_index) := Num.one;
     let gpll1 = get_generations 1 [] [GP_person Num.one p.cle_index None] in
     let gpll = List.rev gpll1 in
@@ -985,11 +985,11 @@ value print_ancestors_same_time_descendants conf base p a =
   in
   let mark = Array.create base.data.persons.len Num.zero in
   let cnt = ref 0 in
-  let rec generation niveau gpl =
+  let rec generation level gpl =
     if List.exists will_print gpl then do {
       html_li conf;
       Wserver.wprint "%s %d\n"
-        (capitale (transl_nth conf "generation/generations" 0)) niveau;
+        (capitale (transl_nth conf "generation/generations" 0)) level;
       tag "ul" begin
         List.iter
           (fun gp ->
@@ -998,7 +998,7 @@ value print_ancestors_same_time_descendants conf base p a =
           gpl;
       end;
       let gpl = next_generation conf base mark gpl in
-      generation (niveau + 1) gpl
+      generation (level + 1) gpl
     }
     else ()
   in
@@ -1009,7 +1009,7 @@ value print_ancestors_same_time_descendants conf base p a =
     else do {
       Wserver.wprint "%s\n"
         (capitale
-           (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+           (transl_a_of_b conf (transl conf "ancestors")
               (gen_person_text raw_access conf base p)));
       Wserver.wprint "%s"
         (transl_decline conf "up to" (person_text conf base a))
@@ -1026,13 +1026,13 @@ value print_ancestors_same_time_descendants conf base p a =
   }
 ;
 
-value afficher_ascendants_niveau conf base niveau_max p =
+value display_ancestors_level conf base max_level p =
   let mark = Array.create base.data.persons.len Num.zero in
   let cnt = ref 0 in
-  let rec generation niveau gpl =
+  let rec generation level gpl =
     do {
       for i = 0 to base.data.persons.len - 1 do { mark.(i) := Num.zero };
-      if niveau < niveau_max then
+      if level < max_level then
         let gpl =
           List.map
             (fun gp ->
@@ -1064,10 +1064,10 @@ value afficher_ascendants_niveau conf base niveau_max p =
                | _ -> [gp :: gpl] ])
             gpl []
         in
-        generation (niveau + 1) gpl
+        generation (level + 1) gpl
       else do {
         html_li conf;
-        Wserver.wprint "%s\n" (capitale (text_level conf niveau_max));
+        Wserver.wprint "%s\n" (capitale (text_level conf max_level));
         tag "ul" begin
           List.iter (print_generation_person conf base cnt) gpl;
         end
@@ -1077,11 +1077,11 @@ value afficher_ascendants_niveau conf base niveau_max p =
   let title h =
     if h then
       Wserver.wprint "%s %d\n"
-        (capitale (transl_nth conf "generation/generations" 0)) niveau_max
+        (capitale (transl_nth conf "generation/generations" 0)) max_level
     else
       Wserver.wprint "%s"
         (capitale
-           (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+           (transl_a_of_b conf (transl conf "ancestors")
               (gen_person_text raw_access conf base p)))
   in
   do {
@@ -1131,14 +1131,14 @@ value print_generation_missing_persons conf base title sp_incl gp =
             | _ -> (1, cpl.father) ]
           in
           Wserver.wprint "%s"
-            (transl_decline2 conf "%1 of %2"
+            (transl_a_of_b conf
                (geneweb_link conf (acces conf base p)
                   (transl_nth conf "husband/wife" parent_name_index))
                (person_title_text conf base (pget conf base conj) ^
                   Date.short_dates_text conf base (pget conf base conj)))
         else do {
-          afficher_personne_titre_referencee conf base p;
-          Date.afficher_dates_courtes conf base p
+          Wserver.wprint "\n%s" (referenced_person_title_text conf base p);
+          Wserver.wprint "%s" (Date.short_dates_text conf base p)
         };
         Wserver.wprint "\n"
       }
@@ -1161,8 +1161,7 @@ value print_generation_missing_persons conf base title sp_incl gp =
         in
         Wserver.wprint "%s\n"
           (if sp_incl then
-             transl_decline2 conf "%1 of %2"
-               (nominative (transl conf "parents")) s
+             transl_a_of_b conf (nominative (transl conf "parents")) s
            else s)
       }
   | _ -> () ]
@@ -1173,19 +1172,19 @@ value one_year base p =
   [ Some (Dgreg d _) -> Some d.year
   | _ ->
       match Adef.od_of_codate p.baptism with
-      [ Some (Dgreg d _) -> Some (annee d)
+      [ Some (Dgreg d _) -> Some (year_of d)
       | _ ->
           match date_of_death p.death with
-          [ Some (Dgreg d _) -> Some (annee d)
+          [ Some (Dgreg d _) -> Some (year_of d)
           | _ ->
               match p.burial with
               [ Buried cod ->
                   match Adef.od_of_codate cod with
-                  [ Some (Dgreg d _) -> Some (annee d)
+                  [ Some (Dgreg d _) -> Some (year_of d)
                   | _ -> None ]
               | Cremated cod ->
                   match Adef.od_of_codate cod with
-                  [ Some (Dgreg d _) -> Some (annee d)
+                  [ Some (Dgreg d _) -> Some (year_of d)
                   | _ -> None ]
               | UnknownBurial -> None ] ] ] ]
 ;
@@ -1202,10 +1201,10 @@ value print_missing_ancestors conf base v spouses_included p =
   let after = p_getint conf.env "after" in
   let before = p_getint conf.env "before" in
   let mark = Array.create base.data.persons.len Num.zero in
-  let rec generation niveau gpl =
-    if niveau > v + 1 then ()
+  let rec generation level gpl =
+    if level > v + 1 then ()
     else if gpl <> [] then do {
-      let title = ref (Some niveau) in
+      let title = ref (Some level) in
       let gpl_to_print =
         List.fold_left
           (fun gpl gp ->
@@ -1231,7 +1230,7 @@ value print_missing_ancestors conf base v spouses_included p =
         gpl_to_print;
       if title.val = None then Wserver.wprint "</ul>\n" else ();
       let gpl = next_generation conf base mark gpl in
-      generation (niveau + 1) gpl
+      generation (level + 1) gpl
     }
     else ()
   in
@@ -1239,7 +1238,8 @@ value print_missing_ancestors conf base v spouses_included p =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "missing ancestors")
+         (transl_a_of_b conf
+            (transl conf "missing ancestors")
             (txt_fun raw_access conf base p)))
   in
   do {
@@ -1257,8 +1257,7 @@ value print_missing_ancestors conf base v spouses_included p =
       html_br conf;
       Wserver.wprint "%s\n"
         (capitale
-           (transl_decline2 conf "%1 of %2"
-              (nominative (transl conf "parents")) "..."))
+           (transl_a_of_b conf (nominative (transl conf "parents")) "..."))
     }
     else ();
     mark.(Adef.int_of_iper p.cle_index) := Num.one;
@@ -1325,14 +1324,14 @@ value val_of_mt =
 ;
 
 value compare base (mt1, p1) (mt2, p2) =
-  let c = alphabetique (p_surname base p1) (p_surname base p2) in
+  let c = alphabetic (p_surname base p1) (p_surname base p2) in
   if c == 0 then
-    let c = alphabetique (p_first_name base p1) (p_first_name base p2) in
+    let c = alphabetic (p_first_name base p1) (p_first_name base p2) in
     if c == 0 then
       if p1 == p2 then val_of_mt mt1 < val_of_mt mt2
       else
         match (Adef.od_of_codate p1.birth, Adef.od_of_codate p2.birth) with
-        [ (Some d1, Some d2) -> d1 strictement_avant d2
+        [ (Some d1, Some d2) -> d1 strictly_before d2
         | _ -> p1.occ < p2.occ ]
     else c < 0
   else c > 0
@@ -1343,13 +1342,13 @@ value print_missing_type conf =
   [ A_person -> ()
   | A_surname_of_husband_of x ->
       Wserver.wprint "%s %s"
-        (transl_decline2 conf "%1 of %2"
+        (transl_a_of_b conf
            (transl_nth conf "surname/surnames" 0)
            (transl_nth conf "husband/wife" 0))
         x
   | A_surname_of_wife_of x ->
       Wserver.wprint "%s %s"
-        (transl_decline2 conf "%1 of %2"
+        (transl_a_of_b conf
            (transl_nth conf "surname/surnames" 0)
            (transl_nth conf "husband/wife" 1))
         x
@@ -1368,8 +1367,8 @@ value print_spouses conf base p u =
        else do {
          Wserver.wprint "\n&amp;%s\n"
            (Date.short_marriage_date_text conf base fam p sp);
-         afficher_personne_titre conf base sp;
-         Date.afficher_dates_courtes conf base sp
+         Wserver.wprint "%s" (person_title_text conf base sp);
+         Wserver.wprint "%s" (Date.short_dates_text conf base sp)
        })
     u.family
 ;
@@ -1380,7 +1379,7 @@ value
   do {
     wprint_geneweb_link conf href (person_text_without_surname conf base p);
     Wserver.wprint "%s %s" begin_surname (person_title_text conf base p);
-    Date.afficher_dates_courtes conf base p;
+    Wserver.wprint "%s" (Date.short_dates_text conf base p);
     if spouses_incl then do {
       Wserver.wprint "\n=&gt; ";
       print_missing_type conf mt;
@@ -1418,21 +1417,22 @@ value print_alphabetic_missing conf base spouses_included (surname, list) =
 
 value print_missing_ancestors_alphabetically conf base v spouses_included p =
   let mark = Array.create base.data.persons.len Num.zero in
-  let rec generation list niveau gpl =
-    if niveau > v then list
+  let rec generation list level gpl =
+    if level > v then list
     else if gpl <> [] then
       let list =
         List.fold_left (add_missing conf base spouses_included) list gpl
       in
       let gpl = next_generation conf base mark gpl in
-      generation list (niveau + 1) gpl
+      generation list (level + 1) gpl
     else list
   in
   let title h =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "missing ancestors")
+         (transl_a_of_b conf
+            (transl conf "missing ancestors")
             (txt_fun raw_access conf base p)))
   in
   let after = p_getint conf.env "after" in
@@ -1487,7 +1487,7 @@ value print_missing_ancestors_alphabetically conf base v spouses_included p =
     let initials =
       List.fold_left
         (fun l (n, _) ->
-           let i = n.[initiale n] in
+           let i = n.[initial n] in
            match l with
            [ [] -> [i]
            | [x :: l'] -> if x = i then l else [i :: l] ])
@@ -1519,7 +1519,7 @@ value print_missing_ancestors_alphabetically conf base v spouses_included p =
       html_br conf;
       Wserver.wprint "%s\n"
         (capitale
-           (transl_decline2 conf "%1 of %2"
+           (transl_a_of_b conf
               (nominative (transl conf "parents")) "..."))
     }
     else ();
@@ -1527,7 +1527,7 @@ value print_missing_ancestors_alphabetically conf base v spouses_included p =
       let _ =
         List.fold_left
           (fun prev_i ((n, _) as e) ->
-             let i = n.[initiale n] in
+             let i = n.[initial n] in
              do {
                if print_initials then
                  match prev_i with
@@ -1645,11 +1645,11 @@ value print_tree_with_table conf base gv p =
                  let cpl = coi base ifam in
                  let fath =
                    let p = pget conf base cpl.father in
-                   if connais base p then Some p else None
+                   if know base p then Some p else None
                  in
                  let moth =
                    let p = pget conf base cpl.mother in
-                   if connais base p then Some p else None
+                   if know base p then Some p else None
                  in
                  match (fath, moth) with
                  [ (Some f, Some m) ->
@@ -1853,7 +1853,7 @@ value print_horizontally conf base max_level p =
     let txt_fun = if h then gen_person_text_no_html else gen_person_text in
     Wserver.wprint "%s"
       (capitale
-         (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+         (transl_a_of_b conf (transl conf "ancestors")
             (txt_fun raw_access conf base p)))
   in
   let max_level = min (limit_by_list conf) max_level in
@@ -1885,16 +1885,11 @@ value print_horizontally conf base max_level p =
     header conf title;
     print_link_to_welcome conf True;
     Wserver.wprint "%s.\n" (capitale (text_to conf max_level));
-    Wserver.wprint "<p>\n";
-(*
-    tag "nobr" begin
-*)
-      let suff13 = "&nbsp;&nbsp;&nbsp;" in
-      let suff2 = "--&nbsp;" in
-      loop 0 suff13 suff2 suff13 p.cle_index;
-(*
-    end;
-*)
+    Wserver.wprint "<table><tr><td nowrap>\n";
+    let suff13 = "&nbsp;&nbsp;&nbsp;" in
+    let suff2 = "--&nbsp;" in
+    loop 0 suff13 suff2 suff13 p.cle_index;
+    Wserver.wprint "</td></tr></table>\n";
     trailer conf
   }
 ;
@@ -1942,7 +1937,7 @@ value print_female_line = print_male_female_line False;
 (* Surnames list *)
 
 value get_date_place conf base auth_for_all_anc p =
-  if auth_for_all_anc || age_autorise conf base p then
+  if auth_for_all_anc || authorized_age conf base p then
     let d1 =
       match Adef.od_of_codate p.birth with
       [ None -> Adef.od_of_codate p.baptism
@@ -1971,7 +1966,7 @@ value get_date_place conf base auth_for_all_anc p =
       else
         match d2 with
         [ Some (Dgreg d _)
-          when (temps_ecoule d conf.today).year > conf.private_years ->
+          when (time_gone_by d conf.today).year > conf.private_years ->
             True
         | _ -> False ]
     in
@@ -2069,7 +2064,7 @@ value build_surnames_list conf base v p =
          let surn = sou base i in
          if surn <> "?" then list.val := [(surn, dp.val) :: list.val] else ())
       ht;
-    Sort.list (fun (s1, _) (s2, _) -> Gutil.alphabetique s1 s2 <= 0) list.val
+    Sort.list (fun (s1, _) (s2, _) -> Gutil.alphabetic s1 s2 <= 0) list.val
   }
 ;
 
@@ -2146,11 +2141,11 @@ value print_surnames_list conf base v p =
 
 value print conf base p =
   match (p_getenv conf.env "t", p_getint conf.env "v") with
-  [ (Some "L", Some v) -> afficher_ascendants_jusqu_a conf base v p
+  [ (Some "L", Some v) -> display_ancestors_upto conf base v p
   | (Some "N", Some v) ->
       if p_getenv conf.env "only" = Some "on" then
-        afficher_ascendants_niveau conf base v p
-      else afficher_ascendants_numerotation conf base v p
+        display_ancestors_level conf base v p
+      else display_ancestors_with_numbers conf base v p
   | (Some "G", Some v) ->
       let ws =
         match p_getenv conf.env "siblings" with
@@ -2162,7 +2157,7 @@ value print conf base p =
         [ Some "on" -> True
         | _ -> False ]
       in
-      afficher_ascendants_numerotation_long conf base v ws wn p
+      display_ancestors_with_numbers_long conf base v ws wn p
   | (Some "M", Some v) ->
       let al =
         match p_getenv conf.env "al" with
@@ -2186,7 +2181,7 @@ value print conf base p =
       | (_, Some v) ->
           print_ancestors_same_time_descendants conf base p
             (pget conf base (Adef.iper_of_int v))
-      | _ -> afficher_menu_ascendants conf base p ]
+      | _ -> display_ancestor_menu conf base p ]
   | (Some "F", Some v) -> print_surnames_list conf base v p
-  | _ -> afficher_menu_ascendants conf base p ]
+  | _ -> display_ancestor_menu conf base p ]
 ;
