@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo *)
-(* $Id: birthday.ml,v 4.5 2002/03/06 12:21:19 ddr Exp $ *)
+(* $Id: birthday.ml,v 4.9 2002/11/18 12:36:26 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -9,7 +9,7 @@ open Gutil;
 
 type date_event = [ DeBirth | DeDeath of death_reason ];
 
-value afficher_anniversaires_jour conf base dead_people liste =
+value print_anniversary_day conf base dead_people liste =
   do {
     Wserver.wprint "<ul>\n";
     List.iter
@@ -57,7 +57,7 @@ value gen_print conf base mois f_scan dead_people =
           [ (Some (Dgreg d _), NotDead | DontKnowIfDead) ->
               if d.prec = Sure && d.day <> 0 && d.month <> 0 &&
                  d.month = mois && d.delta = 0 then
-                if age_autorise conf base p then
+                if authorized_age conf base p then
                   let j = d.day in
                   tab.(pred j) :=
                     [(p, d.year, DeBirth, txt_of) :: tab.(pred j)]
@@ -73,7 +73,7 @@ value gen_print conf base mois f_scan dead_people =
                 [ Some (Dgreg dt _) ->
                     if dt.prec = Sure && dt.day <> 0 && dt.month <> 0 &&
                        dt.month = mois && dt.delta = 0 then
-                      if age_autorise conf base p then
+                      if authorized_age conf base p then
                         let j = dt.day in
                         tab.(pred j) :=
                           [(p, dt.year, DeBirth, txt_of) :: tab.(pred j)]
@@ -86,7 +86,7 @@ value gen_print conf base mois f_scan dead_people =
                     [ Dgreg dt _ ->
                         if dt.prec = Sure && dt.day <> 0 && dt.month <> 0 &&
                            dt.month = mois && dt.delta = 0 then
-                          if age_autorise conf base p then
+                          if authorized_age conf base p then
                             let j = dt.day in
                             let a = dt.year in
                             tab.(pred j) :=
@@ -110,7 +110,7 @@ value gen_print conf base mois f_scan dead_people =
           Sort.list (fun (p1, a1, _, _) (p2, a2, _, _) -> a1 <= a2)
             tab.(pred j)
         in
-        afficher_anniversaires_jour conf base dead_people liste;
+        print_anniversary_day conf base dead_people liste;
       }
       else ()
     };
@@ -119,7 +119,7 @@ value gen_print conf base mois f_scan dead_people =
   }
 ;
 
-value afficher_liste_anniversaires conf base dead_people dt liste =
+value print_anniversary_list conf base dead_people dt liste =
   let a_ref = dt.year in
   do {
     Wserver.wprint "<ul>\n";
@@ -201,9 +201,8 @@ value print_birth_day conf base day_name verb wd dt list =
                   "</b>"))
             verb;
           Wserver.wprint "%s\n"
-            (transl_decline2 conf "%1 of %2" (transl conf "the birthday")
-               "...");
-          afficher_liste_anniversaires conf base False dt list;
+            (transl_a_of_b conf (transl conf "the birthday") "...");
+          print_anniversary_list conf base False dt list;
         } ]
   }
 ;
@@ -227,7 +226,7 @@ value propose_months conf mode =
 
 value day_after d =
   let (day, r) =
-    if d.day >= nb_jours_dans_mois d.month d.year then (1, 1)
+    if d.day >= nb_days_in_month d.month d.year then (1, 1)
     else (succ d.day, 0)
   in
   let (month, r) = if d.month + r > 12 then (1, 1) else (d.month + r, 0) in
@@ -253,7 +252,7 @@ value print_anniv conf base day_name verb wd dt list =
                        Date.code_dmy conf dt) ^
                   "</b>"))
             verb (transl conf "the anniversary");
-          afficher_liste_anniversaires conf base True dt list;
+          print_anniversary_list conf base True dt list;
         } ]
   }
 ;
@@ -280,8 +279,8 @@ value print_marriage conf base month =
             let father = pget conf base cpl.father in
             let mother = pget conf base cpl.mother in
             if m == month &&
-               age_autorise conf base father && not (is_hidden father) &&
-               age_autorise conf base mother && not (is_hidden mother) then
+               authorized_age conf base father && not (is_hidden father) &&
+               authorized_age conf base mother && not (is_hidden mother) then
               tab.(pred d) := [(cpl, y) :: tab.(pred d)]
             else ()
         | _ -> () ]
@@ -301,11 +300,13 @@ value print_marriage conf base month =
                  do {
                    Wserver.wprint "\n";
                    html_li conf;
-                   afficher_personne_titre_referencee conf base
-                     (pget conf base fam.father);
+                   Wserver.wprint "%s"
+                     (referenced_person_title_text conf base
+                        (pget conf base fam.father));
                    Wserver.wprint "\n%s\n" (transl_nth conf "and" 0);
-                   afficher_personne_titre_referencee conf base
-                     (pget conf base fam.mother);
+                   Wserver.wprint "\n%s"
+                     (referenced_person_title_text conf base
+                        (pget conf base fam.mother));
                    Wserver.wprint ", <em>%s %d</em>\n"
                      (transl conf "in (year)") year;
                  })
@@ -326,11 +327,13 @@ value print_anniversaries_of_marriage conf base y list =
          do {
            Wserver.wprint "\n";
            html_li conf;
-           afficher_personne_titre_referencee conf base
-             (pget conf base fam.father);
+           Wserver.wprint "\n%s"
+             (referenced_person_title_text conf base
+                (pget conf base fam.father));
            Wserver.wprint "\n%s\n" (transl_nth conf "and" 0);
-           afficher_personne_titre_referencee conf base
-             (pget conf base fam.mother);
+           Wserver.wprint "\n%s"
+             (referenced_person_title_text conf base
+                (pget conf base fam.mother));
            Wserver.wprint ", <em>%s %d\n(" (transl conf "in (year)") year;
            Wserver.wprint (ftransl conf "%d years ago")
              (conf.today.year - year);
@@ -361,7 +364,7 @@ value print_marriage_day conf base day_name verb wd dt list =
                   "</b>"))
             verb;
           Wserver.wprint "%s\n"
-            (transl_decline2 conf "%1 of %2"
+            (transl_a_of_b conf
                (transl conf "the anniversary of marriage") "...");
           print_anniversaries_of_marriage conf base dt.year list;
         } ]
@@ -369,11 +372,11 @@ value print_marriage_day conf base day_name verb wd dt list =
 ;
 
 value match_dates conf base p d1 d2 =
-  if d1.day == d2.day && d1.month == d2.month then age_autorise conf base p
+  if d1.day == d2.day && d1.month == d2.month then authorized_age conf base p
   else if
     d1.day == 29 && d1.month == 2 && d2.day == 1 && d2.month = 3 &&
     not (leap_year d2.year) then
-    age_autorise conf base p
+    authorized_age conf base p
   else False
 ;
 
@@ -528,13 +531,13 @@ value print_menu_dead conf base =
 
 value match_mar_dates conf base cpl d1 d2 =
   if d1.day == d2.day && d1.month == d2.month then
-    age_autorise conf base (pget conf base cpl.father) &&
-    age_autorise conf base (pget conf base cpl.mother)
+    authorized_age conf base (pget conf base cpl.father) &&
+    authorized_age conf base (pget conf base cpl.mother)
   else if
     d1.day == 29 && d1.month == 2 && d2.day == 1 && d2.month = 3 &&
     not (leap_year d2.year) then
-    age_autorise conf base (pget conf base cpl.father) &&
-    age_autorise conf base (pget conf base cpl.mother)
+    authorized_age conf base (pget conf base cpl.father) &&
+    authorized_age conf base (pget conf base cpl.mother)
   else False
 ;
 
