@@ -1,4 +1,4 @@
-(* $Id: config.mli,v 4.5 2002/03/04 18:01:33 ddr Exp $ *)
+(* $Id: config.mli,v 4.8 2002/10/22 13:18:23 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -17,13 +17,14 @@ type config =
     default_lang : string;
     can_send_image : bool;
     public_if_titles : bool;
+    public_if_no_date : bool;
     cancel_links : mutable bool;
     setup_link : mutable bool;
-    set_cookie : mutable option (string * string);
     access_by_key : bool;
     private_years : int;
     hide_names : bool;
     use_restrict : bool;
+    no_image : bool;
     bname : string;
     env : list (string * string);
     senv : mutable list (string * string);
