@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo *)
-(* $Id: date.ml,v 4.8 2002/03/06 12:21:20 ddr Exp $ *)
+(* $Id: date.ml,v 4.16 2002/12/26 14:26:19 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -54,6 +54,10 @@ value code_dmy conf d =
   code_date conf encoding d.day d.month d.year
 ;
 
+value code_year conf y =
+  code_date conf (transl_nth conf "(date)" 3) 0 0 y
+;
+
 value default_french_month =
   let tab =
     [| "Vendemiaire"; "Brumaire"; "Frimaire"; "Nivose"; "Pluviose"; "Ventose";
@@ -82,6 +86,11 @@ value hebrew_month conf m =
   if r = "[(hebrew month)]" then "[" ^ default_hebrew_month m ^ "]" else r
 ;
 
+value code_french_year conf y =
+  transl_nth conf "year/month/day" 0 ^ " " ^
+    (if y >= 1 && y < 4000 then roman_of_arabian y else string_of_int y)
+;
+
 value code_french_date conf d m y =
   let s =
     if d = 0 then ""
@@ -91,9 +100,7 @@ value code_french_date conf d m y =
     if m = 0 then ""
     else s ^ (if s = "" then "" else " ") ^ french_month conf (m - 1)
   in
-  s ^ (if s = "" then "" else " ") ^ " " ^
-    transl_nth conf "year/month/day" 0 ^ " " ^
-    (if y >= 1 && y < 4000 then roman_of_arabian y else string_of_int y)
+  s ^ (if s = "" then "" else " ") ^ code_french_year conf y
 ;
 
 value code_hebrew_date conf d m y =
@@ -102,10 +109,10 @@ value code_hebrew_date conf d m y =
     if m = 0 then ""
     else s ^ (if s = "" then "" else " ") ^ hebrew_month conf (m - 1)
   in
-  s ^ (if s = "" then "" else " ") ^ " " ^ string_of_int y
+  s ^ (if s = "" then "" else " ") ^ string_of_int y
 ;
 
-value string_of_on_prec_dmy_aux conf sy d =
+value string_of_on_prec_dmy_aux conf code_year sy d =
   match d.prec with
   [ Sure ->
       if d.day = 0 && d.month = 0 then transl conf "in (year)" ^ " " ^ sy
@@ -129,8 +136,7 @@ value string_of_on_prec_dmy_aux conf sy d =
         else if d.day = 0 then transl_decline conf "in (month year)" sy
         else transl_decline conf "on (day month year)" sy
       in
-      s ^ " " ^ transl conf "or" ^ " " ^
-        nominative (code_date conf (transl_nth conf "(date)" 3) 0 0 z)
+      s ^ " " ^ transl conf "or" ^ " " ^ nominative (code_year conf z)
   | YearInt z ->
       let s =
         if d.day = 0 && d.month = 0 then sy
@@ -138,8 +144,7 @@ value string_of_on_prec_dmy_aux conf sy d =
         else transl_decline conf "on (day month year)" sy
       in
       transl conf "between (date)" ^ " " ^ s ^ " " ^
-        transl_nth conf "and" 0 ^ " " ^
-        nominative (code_date conf (transl_nth conf "(date)" 3) 0 0 z) ]
+        transl_nth conf "and" 0 ^ " " ^ nominative (code_year conf z) ]
 ;
 
 value replace_spaces_by_nbsp s =
@@ -149,22 +154,24 @@ value replace_spaces_by_nbsp s =
     else loop (i + 1) (Buff.store len s.[i])
 ;
 
-value string_of_on_prec_dmy conf sy d =
-  let r = string_of_on_prec_dmy_aux conf sy d in replace_spaces_by_nbsp r
+value string_of_on_prec_dmy conf code_dmy sy d =
+  let r = string_of_on_prec_dmy_aux conf code_dmy sy d in
+  replace_spaces_by_nbsp r
 ;
 
 value string_of_on_dmy conf d =
-  let sy = code_dmy conf d in string_of_on_prec_dmy conf sy d
+  let sy = code_dmy conf d in
+  string_of_on_prec_dmy conf code_year sy d
 ;
 
 value string_of_on_french_dmy conf d =
   let sy = code_french_date conf d.day d.month d.year in
-  string_of_on_prec_dmy conf sy d
+  string_of_on_prec_dmy conf code_french_year sy d
 ;
 
 value string_of_on_hebrew_dmy conf d =
   let sy = code_hebrew_date conf d.day d.month d.year in
-  string_of_on_prec_dmy conf sy d
+  string_of_on_prec_dmy conf code_year sy d
 ;
 
 value string_of_prec_dmy conf s d =
@@ -209,12 +216,16 @@ value string_of_ondate conf =
         transl_nth conf "gregorian/julian/french/hebrew" 1 ^ cal_prec
   | Dgreg d Dfrench ->
       let d1 = Calendar.french_of_gregorian d in
-      let s = gregorian_precision conf d in
-      string_of_on_french_dmy conf d1 ^ " " ^ " (" ^ s ^ ")"
+      let s = string_of_on_french_dmy conf d1 in
+      match d.prec with
+      [ Sure -> s ^ " " ^ " (" ^ gregorian_precision conf d ^ ")"
+      | About | Before | After | Maybe | OrYear _ | YearInt _ -> s ]
   | Dgreg d Dhebrew ->
       let d1 = Calendar.hebrew_of_gregorian d in
-      let s = gregorian_precision conf d in
-      string_of_on_hebrew_dmy conf d1 ^ " " ^ " (" ^ s ^ ")"
+      let s = string_of_on_hebrew_dmy conf d1 in
+      match d.prec with
+      [ Sure -> s ^ " " ^ " (" ^ gregorian_precision conf d ^ ")"
+      | About | Before | After | Maybe | OrYear _ | YearInt _ -> s ]
   | Dtext t -> "(" ^ t ^ ")" ]
 ;
 
@@ -236,26 +247,26 @@ value string_of_date conf =
   | Dtext t -> "(" ^ t ^ ")" ]
 ;
 
-value print_age conf a =
+value string_of_age conf a =
   match a with
   [ {day = 0; month = 0; year = y} ->
-      if y > 1 then Wserver.wprint "%d %s" y (transl conf "years old")
-      else if y = 1 then Wserver.wprint "%s" (transl conf "one year old")
-      else Wserver.wprint "%s" (transl conf "birth")
+      if y > 1 then string_of_int y ^ " " ^ transl conf "years old"
+      else if y = 1 then transl conf "one year old"
+      else transl conf "birth"
   | {day = 0; month = m; year = y} ->
-      if y >= 2 then Wserver.wprint "%d %s" y (transl conf "years old")
+      if y >= 2 then string_of_int y ^ " " ^ transl conf "years old"
       else if y > 0 || m > 1 then
-        Wserver.wprint "%d %s" (y * 12 + m) (transl conf "months old")
-      else if m = 1 then Wserver.wprint "%s" (transl conf "one month old")
-      else Wserver.wprint "%s" (transl conf "less than one month old")
+        string_of_int (y * 12 + m) ^ " " ^ transl conf "months old"
+      else if m = 1 then transl conf "one month old"
+      else transl conf "less than one month old"
   | {day = d; month = m; year = y} ->
-      if y >= 2 then Wserver.wprint "%d %s" y (transl conf "years old")
+      if y >= 2 then string_of_int y ^ " " ^ transl conf "years old"
       else if y > 0 || m > 1 then
-        Wserver.wprint "%d %s" (y * 12 + m) (transl conf "months old")
-      else if m = 1 then Wserver.wprint "%s" (transl conf "one month old")
-      else if d >= 2 then Wserver.wprint "%d %s" d (transl conf "days old")
-      else if d == 1 then Wserver.wprint "%s" (transl conf "one day old")
-      else Wserver.wprint "0" ]
+        string_of_int (y * 12 + m) ^ " " ^ transl conf "months old"
+      else if m = 1 then transl conf "one month old"
+      else if d >= 2 then string_of_int d ^ " " ^ transl conf "days old"
+      else if d == 1 then transl conf "one day old"
+      else "0" ]
 ;
 
 value year_text d =
@@ -265,7 +276,7 @@ value year_text d =
     | About | Maybe -> "ca "
     | _ -> "" ]
   in
-  let s = s ^ string_of_int (annee d) in
+  let s = s ^ string_of_int (year_of d) in
   match d.prec with
   [ After -> s ^ "/"
   | OrYear x -> s ^ "/" ^ string_of_int x
@@ -273,8 +284,6 @@ value year_text d =
   | _ -> s ]
 ;
 
-value display_year d = Wserver.wprint "%s" (year_text d);
-
 value of_course_died conf p =
   match Adef.od_of_codate p.birth with
   [ Some (Dgreg d _) -> conf.Config.today.year - d.year > 120
@@ -300,7 +309,7 @@ value get_birth_death_date p =
 ;
 
 value short_dates_text conf base p =
-  if age_autorise conf base p then
+  if authorized_age conf base p then
     let (birth_date, death_date, _) = get_birth_death_date p in
     let s = "" in
     let s =
@@ -328,15 +337,15 @@ value short_dates_text conf base p =
 ;
 
 value short_marriage_date_text conf base fam p1 p2 =
-  if age_autorise conf base p1 && age_autorise conf base p2 then
+  if authorized_age conf base p1 && authorized_age conf base p2 then
     match Adef.od_of_codate fam.marriage with
     [ Some (Dgreg d _) -> "<font size=-2>" ^ year_text d ^ "</font>"
     | _ -> "" ]
   else ""
 ;
 
-value print_place conf pl =
-  Util.copy_string_with_macros conf [] pl
+value string_of_place conf pl =
+  Util.string_with_macros conf False [] pl
 ;
 
 value print_dates conf base p =
@@ -355,7 +364,9 @@ value print_dates conf base p =
         if birth_place <> "" then
           Wserver.wprint "%s\n-&nbsp;" (cap (transl_nth conf "born" is))
         else () ];
-    if birth_place <> "" then print_place conf birth_place else ();
+    if birth_place <> "" then
+      Wserver.wprint "%s" (string_of_place conf birth_place)
+    else ();
     let baptism = Adef.od_of_codate p.baptism in
     let baptism_place = sou base p.baptism_place in
     match baptism with
@@ -370,7 +381,9 @@ value print_dates conf base p =
           Wserver.wprint "%s\n-&nbsp;"
             (cap (transl_nth conf "baptized" is))
         else () ];
-    if baptism_place <> "" then print_place conf baptism_place else ();
+    if baptism_place <> "" then
+      Wserver.wprint "%s" (string_of_place conf baptism_place)
+    else ();
     let death_place = sou base p.death_place in
     match p.death with
     [ Death dr d ->
@@ -403,7 +416,9 @@ value print_dates conf base p =
             }
             else () ]
     | DontKnowIfDead | NotDead -> () ];
-    if death_place <> "" then print_place conf death_place else ();
+    if death_place <> "" then
+      Wserver.wprint "%s" (string_of_place conf death_place)
+    else ();
     let burial_date_place cod =
       let place = sou base p.burial_place in
       do {
@@ -414,7 +429,9 @@ value print_dates conf base p =
                if place <> "" then Wserver.wprint ",\n" else ();
              }
          | None -> if place <> "" then Wserver.wprint " -&nbsp;" else () ];
-         if place <> "" then print_place conf place else ();
+         if place <> "" then
+           Wserver.wprint "%s" (string_of_place conf place)
+         else ();
       }
     in
     match p.burial with
@@ -434,7 +451,7 @@ value print_dates conf base p =
     [ (Some (Dgreg ({prec = Sure | About | Maybe} as d1) _),
        Some (Dgreg ({prec = Sure | About | Maybe} as d2) _))
       when d1 <> d2 ->
-        let a = temps_ecoule d1 d2 in
+        let a = time_gone_by d1 d2 in
         if a.year < 0 || a.year = 0 && a.month = 0 then ()
         else do {
           Wserver.wprint "\n(";
@@ -442,8 +459,7 @@ value print_dates conf base p =
           if not approx && d1.prec = Sure && d2.prec = Sure then ()
           else
             Wserver.wprint "%s " (transl_decline conf "possibly (date)" "");
-          print_age conf a;
-          Wserver.wprint ")";
+          Wserver.wprint "%s)" (string_of_age conf a);
         }
     | _ -> () ];
   }
@@ -644,9 +660,3 @@ value print_calendar conf base =
     trailer conf;
   }
 ;
-
-(* Deprecated *)
-
-value afficher_dates_courtes conf base p =
-  Wserver.wprint "%s" (short_dates_text conf base p)
-;
