@@ -1,5 +1,5 @@
 (* camlp4r ./def.syn.cmo ./pa_html.cmo *)
-(* $Id: family.ml,v 4.19 2002/03/06 12:21:20 ddr Exp $ *)
+(* $Id: family.ml,v 4.30 2002/12/09 22:42:42 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -22,7 +22,7 @@ value select_std_eq base pl k =
     (fun p pl -> if person_is_std_key base p k then [p :: pl] else pl) pl []
 ;
 
-value inconnu_au_bataillon conf =
+value very_unknown conf =
   match (p_getenv conf.env "n", p_getenv conf.env "p") with
   [ (Some nom, Some prenom) ->
       let title _ =
@@ -35,7 +35,7 @@ value inconnu_au_bataillon conf =
   | _ -> incorrect_request conf ]
 ;
 
-value inconnu conf n =
+value unknown conf n =
   let title _ =
     Wserver.wprint "%s: \"%s\"" (capitale (transl conf "not found")) n
   in
@@ -77,22 +77,22 @@ value compact_list conf base xl =
            (Adef.od_of_codate p1.birth, p1.death, Adef.od_of_codate p2.birth,
             p2.death)
          with
-         [ (Some d1, _, Some d2, _) -> d1 strictement_avant d2
+         [ (Some d1, _, Some d2, _) -> d1 strictly_before d2
          | (Some d1, _, _, Death _ d2) ->
-             d1 strictement_avant Adef.date_of_cdate d2
+             d1 strictly_before Adef.date_of_cdate d2
          | (_, Death _ d1, Some d2, _) ->
-             Adef.date_of_cdate d1 strictement_avant d2
+             Adef.date_of_cdate d1 strictly_before d2
          | (_, Death _ d1, _, Death _ d2) ->
-             Adef.date_of_cdate d1 strictement_avant Adef.date_of_cdate d2
+             Adef.date_of_cdate d1 strictly_before Adef.date_of_cdate d2
          | (Some _, _, _, _) -> False
          | (_, Death _ _, _, _) -> False
          | (_, _, Some _, _) -> True
          | (_, _, _, Death _ _) -> True
          | _ ->
-             let c = alphabetique (p_surname base p1) (p_surname base p2) in
+             let c = alphabetic (p_surname base p1) (p_surname base p2) in
              if c == 0 then
                let c =
-                 alphabetique (p_first_name base p1) (p_first_name base p2)
+                 alphabetic (p_first_name base p1) (p_first_name base p2)
                in
                if c == 0 then p1.occ > p2.occ else c > 0
              else c > 0 ])
@@ -174,9 +174,9 @@ value find_all conf base an =
   [ (Some p, Some n) ->
       if n <> Num.zero then
         match Util.branch_of_sosa conf base p.cle_index n with
-        [ Some [(ip, _) :: _] -> [pget conf base ip]
-        | _ -> [] ]
-      else []
+        [ Some [(ip, _) :: _] -> ([pget conf base ip], True)
+        | _ -> ([], False) ]
+      else ([], False)
   | _ ->
       let ipl = person_ht_find_all base an in
       let (an, ipl) =
@@ -209,10 +209,10 @@ value find_all conf base an =
             pl []
         else pl
       in
-      compact_list conf base pl ]
+      (compact_list conf base pl, False) ]
 ;
 
-value precisez conf base n pl =
+value specify conf base n pl =
   let title _ = Wserver.wprint "%s : %s" n (transl conf "specify") in
   let n = Name.crush_lower n in
   let ptll =
@@ -262,7 +262,8 @@ value precisez conf base n pl =
          do {
            html_li conf;
            match tl with
-           [ [] -> afficher_personne_titre_referencee conf base p
+           [ [] ->
+               Wserver.wprint "\n%s" (referenced_person_title_text conf base p)
            | [t :: _] ->
                do {
                  tag "a" "href=\"%s%s\"" (commd conf) (acces conf base p)
@@ -274,8 +275,8 @@ value precisez conf base n pl =
                       Wserver.wprint "%s" (one_title_text conf base p t))
                    tl;
                } ];
-           Date.afficher_dates_courtes conf base p;
-           if age_autorise conf base p then
+           Wserver.wprint "%s" (Date.short_dates_text conf base p);
+           if authorized_age conf base p then
              match p.first_names_aliases with
              [ [] -> ()
              | fnal ->
@@ -311,8 +312,7 @@ value precisez conf base n pl =
                    (person_title_text conf base h) hl
                in
                Wserver.wprint ", <em>%s</em>\n"
-                 (transl_decline2 conf
-                    "%1 of (same or greater generation level) %2"
+                 (transl_a_of_gr_eq_gen_lev conf
                     (transl_nth conf "spouse" (index_of_sex p.sex)) s) ];
          })
       ptll;
@@ -367,7 +367,7 @@ value family_m conf base =
   [ Some "A" ->
       match find_person_in_env conf base "" with
       [ Some p -> Ascend.print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
   | Some "ADD_FAM" when conf.wizard -> UpdateFam.print_add conf base
   | Some "ADD_FAM_OK" when conf.wizard -> UpdateFamOk.print_add conf base
   | Some "ADD_IND" when conf.wizard -> UpdateInd.print_add conf base
@@ -391,14 +391,14 @@ value family_m conf base =
   | Some "C" ->
       match find_person_in_env conf base "" with
       [ Some p -> Cousins.print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
   | Some "CAL" -> Date.print_calendar conf base
   | Some "CHG_CHN" when conf.wizard -> ChangeChildren.print conf base
   | Some "CHG_CHN_OK" when conf.wizard -> ChangeChildren.print_ok conf base
   | Some "D" ->
       match find_person_in_env conf base "" with
       [ Some p -> Descend.print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
   | Some "DAG" -> Dag.print conf base
   | Some "DEL_FAM" when conf.wizard -> UpdateFam.print_del conf base
   | Some "DEL_FAM_OK" when conf.wizard -> UpdateFamOk.print_del conf base
@@ -412,6 +412,7 @@ value family_m conf base =
   | Some "FORUM" -> Forum.print conf base
   | Some "FORUM_ADD" -> Forum.print_add conf base
   | Some "FORUM_ADD_OK" -> Forum.print_add_ok conf base
+  | Some "FORUM_DEL" -> Forum.print_del conf base
   | Some "H" ->
       match p_getenv conf.env "v" with
       [ Some f -> Srcfile.print conf base f
@@ -432,7 +433,7 @@ value family_m conf base =
   | Some "MRG" when conf.wizard ->
       match find_person_in_env conf base "" with
       [ Some p -> Merge.print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
   | Some "MRG_FAM" when conf.wizard -> MergeFam.print conf base
   | Some "MRG_FAM_OK" when conf.wizard -> MergeFamOk.print_merge conf base
   | Some "MRG_MOD_FAM_OK" when conf.wizard ->
@@ -466,17 +467,23 @@ value family_m conf base =
                 Some.surname_print conf base Some.surname_not_found n
               }
           | _ ->
-              if n = "" then inconnu conf n
+              if n = "" then unknown conf n
               else
-                let pl = find_all conf base n in
+                let (pl, soza_acc) = find_all conf base n in
                 match pl with
                 [ [] ->
                     do {
                       conf.cancel_links := False;
-                      Some.surname_print conf base inconnu n
+                      Some.surname_print conf base unknown n
                     }
-                | [p] -> person_selected conf base p
-                | pl -> precisez conf base n pl ] ]
+                | [p] ->
+                    if soza_acc ||
+                       Gutil.person_of_key base n <> None ||
+                       person_is_std_key base p n
+                    then
+                      person_selected conf base p
+                    else specify conf base n pl
+                | pl -> specify conf base n pl ] ]
       | (_, Some i) ->
           relation_print conf base
             (pget conf base (Adef.iper_of_int (int_of_string i)))
@@ -492,7 +499,7 @@ value family_m conf base =
   | Some "R" ->
       match find_person_in_env conf base "" with
       [ Some p -> relation_print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
   | Some "REQUEST" when conf.wizard ->
       let title _ = () in
       do {
@@ -516,12 +523,13 @@ value family_m conf base =
   | Some "U" when conf.wizard ->
       match find_person_in_env conf base "" with
       [ Some p -> Update.print conf base p
-      | _ -> inconnu_au_bataillon conf ]
+      | _ -> very_unknown conf ]
+  | Some "WIZNOTES" -> Wiznotes.print conf base
   | Some mode -> incorrect_request conf
   | None ->
       match find_person_in_env conf base "" with
       [ Some p -> person_selected conf base p
-      | _ -> inconnu_au_bataillon conf ] ]
+      | _ -> very_unknown conf ] ]
 ;
 
 value print_no_index conf base =
