@@ -1,5 +1,5 @@
 (* camlp4r ./pa_lock.cmo ./pa_html.cmo *)
-(* $Id: forum.ml,v 4.15 2002/01/12 14:20:54 ddr Exp $ *)
+(* $Id: forum.ml,v 4.21 2002/12/26 14:26:21 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Util;
@@ -83,8 +83,8 @@ value print_one_header conf prec_date ndisp pos h =
       end;
       tag "td" begin
         if subject = "" || subject = "-" then
-          Wserver.wprint "<em>... %s</em>" (secure (sp2nbsp 30 beg_mess))
-        else Wserver.wprint "%s" (secure (sp2nbsp 30 subject));
+          Wserver.wprint "<em>... %s</em>" (secure (sp2nbsp 50 beg_mess))
+        else Wserver.wprint "%s" (secure (sp2nbsp 50 subject));
       end;
     end;
     ndisp
@@ -133,6 +133,7 @@ value print_headers conf =
               else
                 let (time, s) = get_var ic "Time:" s in
                 let (ident, s) = get_var ic "Ident:" s in
+                let (wizard, s) = get_var ic "Wizard:" s in
                 let (_, s) = get_var ic "Email:" s in
                 let (subject, s) = get_var ic "Subject:" s in
                 let (_, s) = get_var ic "Text:" s in
@@ -231,6 +232,7 @@ value get_message conf pos =
             let s = input_line ic in
             let (time, s) = get_var ic "Time:" s in
             let (ident, s) = get_var ic "Ident:" s in
+            let (wizard, s) = get_var ic "Wizard:" s in
             let (email, s) = get_var ic "Email:" s in
             let (subject, s) = get_var ic "Subject:" s in
             let (_, s) = get_var ic "Text:" s in
@@ -244,8 +246,8 @@ value get_message conf pos =
             in
             if ident <> "" then
               Some
-                (time, ident, email, subject, mess, ic_len - pos_in ic,
-                 ic_len)
+                (time, ident, wizard, email, subject, mess,
+                 ic_len - pos_in ic, ic_len)
             else None
           }
         with
@@ -255,7 +257,7 @@ value get_message conf pos =
   | None -> None ]
 ;
 
-value backward conf pos =
+value backward_pos conf pos =
   let fname = forum_file conf in
   match try Some (open_in_bin fname) with [ Sys_error _ -> None ] with
   [ Some ic ->
@@ -279,14 +281,15 @@ value backward conf pos =
   | None -> pos ]
 ;
 
+value passwd_in_file conf =
+  match p_getenv conf.base_env "wizard_passwd_file" with
+  [ Some "" | None -> False
+  | Some _ -> True ]
+;
+
 value print_forum_message conf base pos =
-  let pos =
-    match p_getenv conf.env "t" with
-    [ Some "back" -> backward conf pos
-    | _ -> pos ]
-  in
   match get_message conf pos with
-  [ Some (time, ident, email, subject, mess, next_pos, forum_length) ->
+  [ Some (time, ident, wizard, email, subject, mess, next_pos, forum_length) ->
       let title _ =
         let subject =
           if subject = "" || subject = "-" then
@@ -304,8 +307,9 @@ value print_forum_message conf base pos =
           Wserver.wprint "<li>";
           if pos = forum_length then Wserver.wprint "&nbsp;"
           else
-            Wserver.wprint "<a href=\"%sm=FORUM;p=%d;t=back\">%s</a>\n"
-              (commd conf) pos (capitale (message_txt conf 3));
+            let back_pos = backward_pos conf pos in
+            Wserver.wprint "<a href=\"%sm=FORUM;p=%d\">%s</a>\n"
+              (commd conf) back_pos (capitale (message_txt conf 3));
           Wserver.wprint "<li>";
           if next_pos > 0 then
             Wserver.wprint "<a href=\"%sm=FORUM;p=%d\">%s</a>\n" (commd conf)
@@ -336,11 +340,26 @@ value print_forum_message conf base pos =
               loop False (Buff.mstore len "<p>\n") (i + 1)
             else loop (mess.[i] = '\n') (Buff.store len mess.[i]) (i + 1)
         in
-        copy_string_with_macros conf [] mess;
-        Wserver.wprint "\n";
+        Wserver.wprint "%s\n" (string_with_macros conf True [] mess);
         if browser_doesnt_have_tables conf then ()
         else Wserver.wprint "</table>";
         Wserver.wprint "</dl>\n";
+        if wizard <> "" && conf.wizard && conf.user = wizard &&
+          passwd_in_file conf
+        then
+          let s = message_txt conf 0 in
+          do {
+            Wserver.wprint "<p>\n";
+            tag "form" "method=post action=\"%s\"" conf.command begin
+              Util.hidden_env conf;
+              Wserver.wprint "<input type=hidden name=m value=FORUM_DEL>\n";
+              Wserver.wprint "<input type=hidden name=p value=%d>\n" pos;
+              Wserver.wprint "<input type=submit value=\"%s\">\n"
+                (capitale
+                   (transl_decline conf "delete" (message_txt conf 0)));
+            end;
+          }
+        else ();
         trailer conf;
       }
   | None -> print_forum_headers conf base ]
@@ -420,6 +439,10 @@ value forum_add conf base ident comm =
             fprintf oc "Time: %04d-%02d-%02d %02d:%02d:%02d\n"
               conf.today.year conf.today.month conf.today.day hh mm ss;
             fprintf oc "Ident: %s\n" ident;
+            if (conf.wizard || conf.just_friend_wizard) && conf.user <> ""
+            then
+              fprintf oc "Wizard: %s\n" conf.user
+            else ();
             if email <> "" then fprintf oc "Email: %s\n" email else ();
             let subject = if subject = "" then "-" else subject in
             fprintf oc "Subject: %s\n" subject;
@@ -478,3 +501,83 @@ value print_add_ok conf base =
     with
     [ Update.ModErr -> () ]
 ;
+
+(* Deleting a message *)
+
+value internal_error conf base =
+  let title _ = Wserver.wprint "%s" (capitale (transl conf "error")) in
+  do {
+    rheader conf title;
+    Wserver.wprint "<em>internal error</em>\n";
+    trailer conf;
+    raise Update.ModErr
+  }
+;
+
+value forum_del conf base pos next_pos =
+  let fname = forum_file conf in
+  let tmp_fname = fname ^ "~" in
+  match try Some (open_in_bin fname) with [ Sys_error _ -> None ] with
+  [ Some ic ->
+      let oc = open_out tmp_fname in
+      let len = in_channel_length ic in
+      let pos = len - pos in
+      let next_pos = len - next_pos in
+      do {
+        loop 0 where rec loop i =
+          if i = len then ()
+          else
+            let c = input_char ic in
+            do {
+              if i < pos || i >= next_pos then output_char oc c
+              else ();
+              loop (i + 1);
+            };
+        close_in ic;
+        close_out oc;
+        try Sys.remove fname with [ Sys_error _ -> () ];
+        Sys.rename tmp_fname fname;
+      }
+  | None -> internal_error conf base ]
+;
+
+value print_del_ok conf base =
+  let title _ =
+    Wserver.wprint "%s" (capitale (transl conf "message deleted"))
+  in
+  do {
+    header conf title;
+    print_link_to_welcome conf True;
+    Wserver.wprint "<a href=\"%sm=FORUM\">%s</a>\n" (commd conf)
+      (capitale (transl conf "database forum"));
+    trailer conf;
+  }
+;
+
+value delete_forum_message conf base pos =
+  let bfile = base_path [] (conf.bname ^ ".gwb") in
+  lock (Iobase.lock_file bfile) with
+  [ Accept ->
+      match get_message conf pos with
+      [ Some
+        (time, ident, wizard, email, subject, mess, next_pos, forum_length) ->
+          if conf.wizard && conf.user <> "" && wizard = conf.user &&
+            passwd_in_file conf
+          then
+            try
+              do {
+                forum_del conf base pos next_pos;
+                print_del_ok conf base;
+              }
+            with
+            [ Update.ModErr -> () ]
+          else print_forum_headers conf base
+      | None -> print_forum_headers conf base ]
+  | Refuse -> Update.error_locked conf base ]
+;
+
+value print_del conf base =
+  match p_getint conf.env "p" with
+  [ Some pos -> delete_forum_message conf base pos
+  | None -> print_forum_headers conf base ]
+;
