@@ -1,10 +1,11 @@
 (* camlp4r pa_extend.cmo ./pa_html.cmo ./pa_lock.cmo *)
-(* $Id: gwd.ml,v 4.40 2002/03/08 10:03:27 ddr Exp $ *)
+(* $Id: gwd.ml,v 4.52 2002/12/30 18:40:04 ddr Exp $ *)
 (* Copyright (c) 2002 INRIA *)
 
 open Config;
 open Def;
 open Gutil;
+open Util;
 open Printf;
 
 value green_color = "#2f6400";
@@ -214,8 +215,7 @@ value input_lexicon lang =
   try
     let ic =
       open_in
-        (List.fold_right Filename.concat [Util.lang_dir.val; "lang"]
-           "lexicon.txt")
+        (Util.search_in_lang_path (Filename.concat "lang" "lexicon.txt"))
     in
     let derived_lang =
       match Gutil.lindex lang '-' with
@@ -269,8 +269,7 @@ value alias_lang lang =
   if String.length lang < 2 then lang
   else
     let fname =
-      List.fold_right Filename.concat [Util.lang_dir.val; "lang"]
-        "alias_lg.txt"
+      Util.search_in_lang_path (Filename.concat "lang" "alias_lg.txt")
     in
     match try Some (open_in fname) with [ Sys_error _ -> None ] with
     [ Some ic ->
@@ -345,7 +344,7 @@ value print_renamed conf new_n =
     "http://" ^ Util.get_server_string conf ^ new_req
   in
   let env =
-    [('o', fun _ -> conf.bname); ('n', fun _ -> new_n); ('l', link)]
+    [('o', fun _ -> conf.bname); ('e', fun _ -> new_n); ('l', link)]
   in
   match Util.open_etc_file "renamed" with
   [ Some ic ->
@@ -488,66 +487,16 @@ value unauth_server conf passwd =
     in
     Wserver.wprint "\
 <head>
-<title>%s %s access failed</title>
-<meta http-equiv=\"REFRESH\" content=\"2;URL=%s\">
+<title>%s access failed for database %s</title>
 </head>
-" typ conf.bname url;
-    Wserver.wprint "<body><h1>%s %s access failed</h1></body>\n" typ
-      conf.bname;
+" typ conf.bname;
+    Wserver.wprint "<body><h1>%s access failed for database %s</h1>"
+      typ conf.bname;
+    Wserver.wprint "Return to <a href=\"%s\">welcome page</a>\n" url;
+    Wserver.wprint "</body>\n";
   }
 ;
 
-value unauth_cgi conf passwd =
-  let title _ =
-    let i = if passwd = "w" then 0 else 1 in
-    Wserver.wprint "%s / %s"
-      (Util.capitale (Util.transl_nth conf "wizard/friend" i)) conf.bname
-  in
-  let message_txt i = Util.transl_nth conf "user/password/cancel" i in
-  do {
-    conf.set_cookie := Some (conf.bname ^ "_" ^ passwd, "");
-    Util.header conf title;
-    Wserver.wprint "<div align=center><table border=0><tr><td>\n";
-    tag "form" "method=POST action=\"%s\"" conf.command begin
-      Util.hidden_env conf;
-      List.iter
-        (fun (k, v) ->
-           if List.mem k ["log_pwd"; "log_uid"; "log_cnl"] then ()
-           else
-             Wserver.wprint "<input type=hidden name=%s value=\"%s\">\n" k
-               (Util.quote_escaped (Util.decode_varenv v)))
-        conf.env;
-      tag "table" "border=1" begin
-        tag "tr" "align=left" begin
-          tag "td" "align=right" begin
-            Wserver.wprint "%s:" (Util.capitale (message_txt 0));
-          end;
-          tag "td" "align=left" begin
-            Wserver.wprint "<input name=\"log_uid\" size=30>\n";
-          end;
-        end;
-        tag "tr" "align=left" begin
-          tag "td" "align=right" begin
-            Wserver.wprint "%s:" (Util.capitale (message_txt 1));
-          end;
-          tag "td" "align=left" begin
-            Wserver.wprint "<input name=\"log_pwd\" type=password size=30>\n";
-          end;
-        end;
-      end;
-      Wserver.wprint "<input type=submit value=Ok>\n";
-      Wserver.wprint "<input type=submit name=log_cnl value=\"%s\">\n"
-        (Util.capitale (message_txt 2));
-    end;
-    Wserver.wprint "</td></tr></table></div>\n";
-    Util.trailer conf;
-  }
-;
-
-value unauth conf passwd =
-  if conf.cgi then unauth_cgi conf passwd else unauth_server conf passwd
-;
-
 value match_auth_file auth_file uauth =
   if auth_file = "" then False
   else
@@ -592,11 +541,11 @@ type access_type =
   [ ATwizard of string | ATfriend of string | ATnormal | ATnone | ATset ]
 ;
 
-value compatible_tokens (addr1, base1_pw1) (addr2, base2_pw2) =
-  (*addr1 = addr2 && *)base1_pw1 = base2_pw2
+value compatible_tokens check_from (addr1, base1_pw1) (addr2, base2_pw2) =
+  (not check_from || addr1 = addr2) && base1_pw1 = base2_pw2
 ;
 
-value get_actlog utm from_addr base_password =
+value get_actlog check_from utm from_addr base_password =
   let fname = Srcfile.adm_file "actlog" in
   match try Some (open_in fname) with [ Sys_error _ -> None ] with
   [ Some ic ->
@@ -619,7 +568,8 @@ value get_actlog utm from_addr base_password =
             let (list, r, changed) =
               if utm -. tm >= tmout then (list, r, True)
               else if
-                compatible_tokens (addr, db_pwd) (from_addr, base_password)
+                compatible_tokens check_from (addr, db_pwd)
+                  (from_addr, base_password)
               then
                 let r = if c = 'w' then ATwizard user else ATfriend user in
                 ([((from_addr, db_pwd), (utm, c, user)) :: list], r, True)
@@ -643,21 +593,25 @@ value get_actlog utm from_addr base_password =
 
 value set_actlog list =
   let fname = Srcfile.adm_file "actlog" in
-  let oc = open_out fname in
-  do {
-    List.iter
-      (fun ((from, base_pw), (a, c, d)) ->
-         fprintf oc "%.0f %s/%s %c%s\n" a from base_pw c
-           (if d = "" then "" else " " ^ d))
-      list;
-    close_out oc;
-  }
+  match try Some (open_out fname) with [ Sys_error _ -> None ] with
+  [ Some oc ->
+      do {
+        List.iter
+          (fun ((from, base_pw), (a, c, d)) ->
+             fprintf oc "%.0f %s/%s %c%s\n" a from base_pw c
+               (if d = "" then "" else " " ^ d))
+          list;
+        close_out oc;
+      }
+  | None -> () ]
 ;
 
-value get_token utm from_addr base_password =
+value get_token check_from utm from_addr base_password =
   lock_wait Srcfile.adm_file "gwd.lck" with
   [ Accept ->
-      let (list, r, changed) = get_actlog utm from_addr base_password in
+      let (list, r, changed) =
+        get_actlog check_from utm from_addr base_password
+      in
       do { if changed then set_actlog list else (); r }
   | Refuse -> ATnormal ]
 ;
@@ -680,7 +634,7 @@ value set_token utm from_addr base_file acc user =
   [ Accept ->
       do {
         random_self_init ();
-        let (list, _, _) = get_actlog utm "" "" in
+        let (list, _, _) = get_actlog False utm "" "" in
         let (x, xx) =
           let base = base_file ^ "_" in
           let rec loop ntimes =
@@ -689,7 +643,8 @@ value set_token utm from_addr base_file acc user =
               let x = mkpasswd () in
               let xx = base ^ x in
               if List.exists
-                   (fun (tok, _) -> compatible_tokens tok (from_addr, xx))
+                   (fun (tok, _) ->
+                      compatible_tokens False tok (from_addr, xx))
                    list
               then
                 loop (ntimes - 1)
@@ -819,17 +774,8 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
         in
         let access_type =
           match passwd with
-          [ "" -> ATnone
-          | "w" | "f" ->
-              if cgi then
-                let cookie = Wserver.extract_param "cookie: " '\n' request in
-                let cookenv = Util.create_env cookie in
-                let k = base_file ^ "_" ^ passwd in
-                let v = try List.assoc k cookenv with [ Not_found -> "" ] in
-                if v = "" then ATnone
-                else get_token utm from_addr (base_file ^ "_" ^ v)
-              else ATnone
-          | _ -> get_token utm from_addr base_passwd ]
+          [ "" | "w" | "f" -> ATnone
+          | _ -> get_token True utm from_addr base_passwd ]
         in
         (passwd, env, access_type)
     in
@@ -889,21 +835,11 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
         [ Not_found -> False ]
     in
     let passwd1 =
-      if cgi then
-        match (Util.p_getenv env "log_uid", Util.p_getenv env "log_pwd") with
-        [ (Some uid, Some pwd) -> uid ^ ":" ^ pwd
-        | _ -> "" ]
+      let auth = Wserver.extract_param "authorization: " '\r' request in
+      if auth = "" then ""
       else
-        let auth = Wserver.extract_param "authorization: " '\r' request in
-        if auth = "" then ""
-        else
-          let i = String.length "Basic " in
-          Base64.decode (String.sub auth i (String.length auth - i))
-    in
-    let passwd =
-      match Util.p_getenv env "log_cnl" with
-      [ Some "" | None -> passwd
-      | Some _ -> "" ]
+        let i = String.length "Basic " in
+        Base64.decode (String.sub auth i (String.length auth - i))
     in
     let uauth = if passwd = "w" || passwd = "f" then passwd1 else passwd in
     let (ok, wizard, friend) =
@@ -912,7 +848,7 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
       | ATfriend user -> (True, False, True)
       | ATnormal -> (True, False, False)
       | ATnone | ATset ->
-          if passwd = "w" || passwd = "f" then
+          if not cgi && (passwd = "w" || passwd = "f") then
             if passwd = "w" then
               if wizard_passwd = "" && wizard_passwd_file = "" then
                 (True, True, friend_passwd = "")
@@ -947,34 +883,22 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
           | ATfriend user -> user
           | _ -> "" ] ]
     in
-    let (command, passwd, set_cookie) =
+    let (command, passwd) =
       match access_type with
-      [ ATnone | ATset ->
-          if cgi then
-            let has_accepted_cookie =
-              Wserver.extract_param "cookie: " '\n' request <> ""
-            in
-            if passwd = "" then (command, "", None)
-            else if wizard then
-              let pwd_id = set_token utm from_addr base_file 'w' user in
-              if has_accepted_cookie then
-                (command, passwd, Some (base_file ^ "_w", pwd_id))
-              else
-                (command, pwd_id, None)
-            else if friend then
-              let pwd_id = set_token utm from_addr base_file 'f' user in
-              if has_accepted_cookie then
-                (command, passwd, Some (base_file ^ "_f", pwd_id))
-              else
-                (command, pwd_id, None)
-            else (command, passwd, None)
-          else if passwd = "" then (base_file, "", None)
-          else (base_file ^ "_" ^ passwd, passwd, None)
-      | ATnormal -> if cgi then (command, "", None) else (base_file, "", None)
+      [ ATset ->
+          if wizard then
+            let pwd_id = set_token utm from_addr base_file 'w' user in
+            if cgi then (command, pwd_id) else (base_file ^ "_" ^ pwd_id, "")
+          else if friend then
+            let pwd_id = set_token utm from_addr base_file 'f' user in
+            if cgi then (command, pwd_id) else (base_file ^ "_" ^ pwd_id, "")
+          else if cgi then (command, "")
+          else (base_file, "")
+      | ATnormal -> if cgi then (command, "") else (base_file, "")
       | _ ->
-          if cgi then (command, passwd, None)
-          else if passwd = "" then (base_file, "", None)
-          else (base_file ^ "_" ^ passwd, passwd, None) ]
+          if cgi then (command, passwd)
+          else if passwd = "" then (base_file, "")
+          else (base_file ^ "_" ^ passwd, passwd) ]
     in
     let passwd1 =
       match lindex passwd1 ':' with
@@ -1003,9 +927,11 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
        public_if_titles =
          try List.assoc "public_if_titles" base_env = "yes" with
          [ Not_found -> False ];
+       public_if_no_date =
+         try List.assoc "public_if_no_date" base_env = "yes" with
+         [ Not_found -> False ];
        cancel_links = cancel_links;
        setup_link = setup_link.val;
-       set_cookie = set_cookie;
        access_by_key =
          try List.assoc "access_by_key" base_env = "yes" with
          [ Not_found -> False ];
@@ -1022,6 +948,11 @@ value make_conf cgi from_addr (addr, request) script_name contents env =
          else
            try List.assoc "use_restrict" base_env = "yes" with
            [ Not_found -> False ];
+       no_image =
+         if wizard || friend then False
+         else
+           try List.assoc "no_image_for_visitor" base_env = "yes" with
+           [ Not_found -> False ];
        bname = base_file; env = env; senv = [];
        henv =
          (if not cgi then []
@@ -1172,7 +1103,7 @@ value conf_and_connection cgi from (addr, request) script_name contents env =
                   flush_log oc;
                 }
             | Refuse -> () ];
-            unauth conf passwd;
+            unauth_server conf passwd;
           }
       | _ ->
           let mode = Util.p_getenv conf.env "m" in
@@ -1393,7 +1324,7 @@ value geneweb_server () =
         | None -> try Unix.gethostname () with _ -> "computer" ]
       in
       eprintf "GeneWeb %s - " Version.txt;
-      eprintf "Copyright (c) 2002 INRIA\n";
+      eprintf "Copyright (c) 2003 INRIA\n";
       if not daemon.val then do {
         eprintf "Possible addresses:";
         eprintf "
@@ -1523,9 +1454,25 @@ value slashify s =
   }
 ;
 
-value available_languages =
-  ["cn"; "cs"; "de"; "dk"; "en"; "es"; "eo"; "fr"; "he"; "it"; "nl"; "no";
-   "pt"; "se"]
+value mkdir_p x =
+  loop x where rec loop x =
+    do  {
+      let y = Filename.dirname x;
+      if y <> x && String.length y < String.length x then loop y else ();
+      try Unix.mkdir x 0o755 with [ Unix.Unix_error _ _ _ -> () ];
+    }
+;
+
+value make_cnt_dir x =
+  do {
+    mkdir_p x;
+    ifdef WIN95 then do {
+      Wserver.sock_in.val := Filename.concat x "gwd.sin";
+      Wserver.sock_out.val := Filename.concat x "gwd.sou";
+    }
+    else ();
+    Util.cnt_dir.val := x;
+  }
 ;
 
 value main () =
@@ -1539,25 +1486,15 @@ value main () =
       " [options] where options are:"
     in
     let speclist =
-      [("-hd", Arg.String (fun x -> Util.lang_dir.val := x),
+      [("-hd",
+        Arg.String (fun x -> Util.lang_path.val := [x :: Util.lang_path.val]),
         "<dir>\n       Directory where the directory lang is installed.");
-       ("-dd", Arg.String (fun x -> Util.doc_dir.val := x),
+       ("-dd",
+        Arg.String (fun x -> Util.doc_path.val := [x :: Util.doc_path.val]),
         "<dir>\n       Directory where the documentation is installed.");
        ("-bd", Arg.String (fun x -> Util.base_dir.val := x),
         "<dir>\n       Directory where the databases are installed.");
-       ("-wd",
-        Arg.String
-          (fun x ->
-             do {
-               try Unix.mkdir x 0o755 with [ Unix.Unix_error _ _ _ -> () ];
-               ifdef WIN95 then do {
-                 Wserver.sock_in.val := Filename.concat x "gwd.sin";
-                 Wserver.sock_out.val := Filename.concat x "gwd.sou";
-               }
-               else ();
-               Util.cnt_dir.val := x;
-             }),
-        "\
+       ("-wd", Arg.String make_cnt_dir, "\
 <dir>
        Directory for socket communication (Windows) and access count.");
        ("-cgi", Arg.Set cgi, "\n       Force cgi mode.");
@@ -1627,12 +1564,12 @@ s)"); ("-redirect", Arg.String (fun x -> redirected_addr.val := Some x), "\
     ifdef UNIX then
       default_lang.val :=
         let s = try Sys.getenv "LANG" with [ Not_found -> "" ] in
-        if List.mem s available_languages then s
+        if List.mem s Version.available_languages then s
         else
           let s = try Sys.getenv "LC_CTYPE" with [ Not_found -> "" ] in
           if String.length s >= 2 then
             let s = String.sub s 0 2 in
-            if List.mem s available_languages then s else "en"
+            if List.mem s Version.available_languages then s else "en"
           else "en"
     else ();
     arg_parse_in_file (chop_extension Sys.argv.(0) ^ ".arg") speclist anonfun
@@ -1640,19 +1577,19 @@ s)"); ("-redirect", Arg.String (fun x -> redirected_addr.val := Some x), "\
     Argl.parse speclist anonfun usage;
     if images_dir.val <> "" then
       let abs_dir =
-        let abs_path =
-          if Filename.is_relative images_dir.val then
-            if Filename.is_relative Util.lang_dir.val then
-              [Sys.getcwd (); Util.lang_dir.val]
-            else [Util.lang_dir.val]
-          else []
+        let f =
+          Util.search_in_lang_path
+            (Filename.concat images_dir.val "gwback.jpg")
         in
-        List.fold_right Filename.concat abs_path images_dir.val
+        let d = Filename.dirname f in
+        if Filename.is_relative d then Filename.concat (Sys.getcwd ()) d
+        else d
       in
       Util.images_url.val := "file://" ^ slashify abs_dir
     else ();
-    if Util.doc_dir.val = "" then
-      Util.doc_dir.val := Filename.concat Util.lang_dir.val "doc"
+    if Util.doc_path.val = [] then
+      Util.doc_path.val :=
+        List.map (fun d -> Filename.concat d "doc") Util.lang_path.val
     else ();
     if Util.cnt_dir.val = "" then Util.cnt_dir.val := Util.base_dir.val
     else ();
