@@ -1,4 +1,4 @@
-(* $Id: gwu.ml,v 4.11 2002/01/12 14:20:56 ddr Exp $ *)
+(* $Id: gwu.ml,v 4.13 2002/10/22 13:18:24 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -73,7 +73,7 @@ value print_date_option oc =
 
 value starting_char s =
   match s.[0] with
-  [ 'a'..'z' | 'A'..'Z' | ''..'' | ''..'' -> True
+  [ 'a'..'z' | 'A'..'Z' | ''..'' | ''..'' | '0'..'9' -> True
   | '?' -> if s = "?" then True else False
   | _ -> False ]
 ;
@@ -898,8 +898,8 @@ value mark_one_connex_component base mark ifam =
   else do {
     eprintf "%s: group of size %d not included\n" origin_file len;
     let cpl = coi base ifam in
-    eprintf "    %s + %s\n" (denomination base (poi base cpl.father))
-      (denomination base (poi base cpl.mother));
+    eprintf "    %s + %s\n" (designation base (poi base cpl.father))
+      (designation base (poi base cpl.mother));
     flush stderr;
     set_mark Scanned
   }
