@@ -1,4 +1,4 @@
-(* $Id: iobase.ml,v 4.13 2002/01/30 11:49:50 ddr Exp $ *)
+(* $Id: iobase.ml,v 4.15 2002/03/15 19:18:51 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Def;
@@ -147,7 +147,7 @@ value index_of_string strings ic start_pos hash_len string_patches s =
 (* Search index of a given surname or given first name in file strings.inx *)
 
 value name_key s =
-  let i = initiale s in
+  let i = Gutil.initial s in
   let s =
     if i == 0 then s
     else String.sub s i (String.length s - i) ^ " " ^ String.sub s 0 i
@@ -442,7 +442,7 @@ value make_visible_cache bname persons =
 
 (* Input *)
 
-value apply_patches tab patches plen =
+value apply_patches tab f patches plen =
   if plen = 0 then tab
   else do {
     let new_tab =
@@ -453,7 +453,7 @@ value apply_patches tab patches plen =
       }
       else tab
     in
-    Hashtbl.iter (fun i v -> new_tab.(i) := v) patches;
+    Hashtbl.iter (fun i v -> new_tab.(i) := f v) patches;
     new_tab
   }
 ;
@@ -512,7 +512,83 @@ value check_magic =
     }
 ;
 
+value phony_person =
+  {first_name = 0; surname = 0;
+   occ = 0; image = 0; first_names_aliases = [];
+   surnames_aliases = []; public_name = 0; qualifiers = [];
+   aliases = []; titles = []; rparents = []; related = [];
+   occupation = 0; sex = Neuter; access = IfTitles;
+   birth = Adef.codate_None; birth_place = 0;
+   birth_src = 0; baptism = Adef.codate_None;
+   baptism_place = 0; baptism_src = 0;
+   death = DontKnowIfDead; death_place = 0;
+   death_src = 0; burial = UnknownBurial;
+   burial_place = 0; burial_src = 0;
+   notes = 0; psources = 0;
+   cle_index = Adef.iper_of_int 0}
+;
+
+value phony_family =
+  {marriage = Adef.codate_None;
+   marriage_place = 0; marriage_src = 0;
+   witnesses = [| |]; relation = Married;
+   divorce = NotDivorced; comment = 0;
+   origin_file = 0; fsources = 0;
+   fam_index = Adef.ifam_of_int 0}
+;
+
+value ext phony v =
+  let rlen = Array.length (Obj.magic v) in
+  let alen = Array.length (Obj.magic phony) in
+  if rlen = alen then v
+  else if rlen < alen then do {
+    let x = Array.copy (Obj.magic phony) in
+    Array.blit (Obj.magic v) 0 x 0 rlen;
+    Obj.magic x
+  }
+  else
+    failwith "this is a GeneWeb base, but not compatible; please upgrade"
+;
+
+value array_ext phony fa =
+  let a = Obj.magic fa in
+  if Array.length a = 0 then fa
+  else
+    let rlen = Array.length a.(0) in
+    let alen = Array.length (Obj.magic phony) in
+    if rlen = alen then fa
+    else if rlen < alen then do {
+      ifdef UNIX then
+        if verbose.val then do {
+          Printf.eprintf
+            "*** extending records from size %d to size %d\n" 
+            rlen alen;
+          flush stderr;
+        }
+        else ()
+      else ();      
+      for i = 0 to Array.length a - 1 do {
+        let x = Array.copy (Obj.magic phony) in
+        Array.blit a.(i) 0 x 0 rlen;
+        a.(i) := x;
+      };
+      fa
+    }
+    else
+      failwith "this is a GeneWeb base, but not compatible; please upgrade"
+;
+
 value make_cache ic ic_acc shift array_pos (plenr, patches) len name =
+  let v_ext v =
+    if name = "persons" then ext phony_person v
+    else if name = "families" then ext phony_family v
+    else v
+  in
+  let v_arr_ext v =
+    if name = "persons" then array_ext phony_person v
+    else if name = "families" then array_ext phony_family v
+    else v
+  in
   let tab = ref None in
   let cleared = ref False in
   let r =
@@ -535,7 +611,8 @@ value make_cache ic ic_acc shift array_pos (plenr, patches) len name =
           do {
             seek_in ic array_pos;
             let v = input_value ic in
-            let t = apply_patches v patches r.len in
+            let v = v_arr_ext v in
+            let t = apply_patches v v_ext patches r.len in
             tab.val := Some t;
             t
           }
@@ -544,7 +621,10 @@ value make_cache ic ic_acc shift array_pos (plenr, patches) len name =
   let gen_get i =
     if tab.val <> None then (r.array ()).(i)
     else
-      try Hashtbl.find patches i with
+      try
+        let v = Hashtbl.find patches i in
+        v_ext v
+      with
       [ Not_found ->
           if i < 0 || i >= len then
             failwith
@@ -553,7 +633,8 @@ value make_cache ic ic_acc shift array_pos (plenr, patches) len name =
             seek_in ic_acc (shift + Iovalue.sizeof_long * i);
             let pos = input_binary_int ic_acc in
             seek_in ic pos;
-            Iovalue.input ic
+            let v = Iovalue.input ic in
+            v_ext v
           } ]
   in
   do { r.array := array; r.get := gen_get; r }
