@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo ./pa_lock.cmo *)
-(* $Id: mergeInd.ml,v 4.16 2002/03/06 12:21:21 ddr Exp $ *)
+(* $Id: mergeInd.ml,v 4.21 2002/06/03 13:29:27 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Config;
@@ -246,12 +246,12 @@ value propose_merge_ind conf base branches p1 p2 =
              do {
                tag "tr" "align=left" begin
                  tag "td" begin
-                   afficher_personne_referencee conf base p1;
-                   Date.afficher_dates_courtes conf base p1;
+                   Wserver.wprint "\n%s" (referenced_person_text conf base p1);
+                   Wserver.wprint "%s" (Date.short_dates_text conf base p1);
                  end;
                  tag "td" begin
-                   afficher_personne_referencee conf base p2;
-                   Date.afficher_dates_courtes conf base p2;
+                   Wserver.wprint "\n%s" (referenced_person_text conf base p2);
+                   Wserver.wprint "%s" (Date.short_dates_text conf base p2);
                  end;
                end;
              })
@@ -309,18 +309,33 @@ value effective_merge_ind conf base p1 p2 =
     if p1.birth_place = Adef.istr_of_int 0 then
       p1.birth_place := p2.birth_place
     else ();
+    if p1.birth_src = Adef.istr_of_int 0 then
+      p1.birth_src := p2.birth_src
+    else ();
     if p1.baptism = Adef.codate_None then p1.baptism := p2.baptism else ();
     if p1.baptism_place = Adef.istr_of_int 0 then
       p1.baptism_place := p2.baptism_place
     else ();
+    if p1.baptism_src = Adef.istr_of_int 0 then
+      p1.baptism_src := p2.baptism_src
+    else ();
     if p1.death = DontKnowIfDead then p1.death := p2.death else ();
     if p1.death_place = Adef.istr_of_int 0 then
       p1.death_place := p2.death_place
     else ();
+    if p1.death_src = Adef.istr_of_int 0 then
+      p1.death_src := p2.death_src
+    else ();
     if p1.burial = UnknownBurial then p1.burial := p2.burial else ();
     if p1.burial_place = Adef.istr_of_int 0 then
       p1.burial_place := p2.burial_place
     else ();
+    if p1.burial_src = Adef.istr_of_int 0 then
+      p1.burial_src := p2.burial_src
+    else ();
+    if p1.occupation = Adef.istr_of_int 0 then
+      p1.occupation := p2.occupation
+    else ();
     if p1.notes = Adef.istr_of_int 0 then p1.notes := p2.notes else ();
     UpdateIndOk.effective_del conf base p2;
     base.func.patch_person p1.cle_index p1;
@@ -369,6 +384,18 @@ value effective_merge_fam conf base fam1 fam2 p1 p2 =
   let des1 = doi base fam1.fam_index in
   let des2 = doi base fam2.fam_index in
   do {
+    if fam1.marriage = Adef.codate_None then fam1.marriage := fam2.marriage
+    else ();
+    if fam1.marriage_place = Adef.istr_of_int 0 then
+      fam1.marriage_place := fam2.marriage_place
+    else ();
+    if fam1.marriage_src = Adef.istr_of_int 0 then
+      fam1.marriage_src := fam2.marriage_src
+    else ();
+    if fam1.fsources = Adef.istr_of_int 0 then
+      fam1.fsources := fam2.fsources
+    else ();
+    base.func.patch_family fam1.fam_index fam1;
     des1.children := Array.append des1.children des2.children;
     base.func.patch_descend fam1.fam_index des1;
     for i = 0 to Array.length des2.children - 1 do {
@@ -470,7 +497,7 @@ value print_merged conf base p =
   do {
     header conf title;
     print_link_to_welcome conf True;
-    afficher_personne_referencee conf base p;
+    Wserver.wprint "\n%s" (referenced_person_text conf base p);
     Wserver.wprint "\n";
     trailer conf;
   }
