@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo *)
-(* $Id: relation.ml,v 4.25 2002/03/06 12:21:23 ddr Exp $ *)
+(* $Id: relation.ml,v 4.35 2002/11/28 14:10:54 ddr Exp $ *)
 (* Copyright (c) 2002 INRIA *)
 
 open Def;
@@ -58,7 +58,7 @@ value print_with_witness conf base p fam ip =
 ;
 
 value print_menu conf base p =
-  let auth = age_autorise conf base p in
+  let auth = authorized_age conf base p in
   let title h =
     do {
       Wserver.wprint "%s " (capitale (transl conf "link between"));
@@ -371,6 +371,7 @@ value next_relation_link_txt conf ip1 ip2 excl_faml =
   "href=\"" ^ commd conf ^ "em=R;ei=" ^
     string_of_int (Adef.int_of_iper ip1) ^ ";i=" ^
     string_of_int (Adef.int_of_iper ip2) ^
+    (if p_getenv conf.env "spouse" = Some "on" then ";spouse=on" else "") ^
     (if conf.cancel_links then ";cgl=on" else "") ^ ";et=S" ^
     fst
       (List.fold_left
@@ -697,9 +698,11 @@ value parents_label conf base info =
           (transl_nth conf "nth (generation)" n) ]
 ;
 
-value parent_in_law_label conf sex =
-  let is = index_of_sex sex in
-  transl_nth conf "the father-in-law/the mother-in-law" is
+value parent_in_law_label conf child_sex parent_sex =
+  let txt = transl conf "the father-in-law/the mother-in-law" in
+  let is = index_of_sex parent_sex in
+  if nb_fields txt = 2 then nth_field txt is
+  else nth_field txt (2 * index_of_sex child_sex + is)
 ;
 
 value ancestor_label conf base info x sex =
@@ -735,9 +738,11 @@ value ancestor_label conf base info x sex =
           (transl_nth conf "nth (generation)" n) ]
 ;
 
-value child_in_law_label conf sex =
-  let is = index_of_sex sex in
-  transl_nth conf "a son-in-law/a daughter-in-law" is
+value child_in_law_label conf sex_child sex_parent =
+  let txt = transl conf "a son-in-law/a daughter-in-law" in
+  let is = index_of_sex sex_child in
+  if nb_fields txt = 2 then nth_field txt is
+  else nth_field txt (2 * index_of_sex sex_parent + is)
 ;
 
 value descendant_label conf base info x p =
@@ -796,9 +801,11 @@ value half_brother_label conf sex =
   transl_nth conf "a half-brother/a half-sister/a half-sibling" is
 ;
 
-value brother_in_law_label conf sex =
-  let is = index_of_sex sex in
-  transl_nth conf "a brother-in-law/a sister-in-law" is
+value brother_in_law_label conf brother_sex self_sex =
+  let txt = transl conf "a brother-in-law/a sister-in-law" in
+  let is = index_of_sex brother_sex in
+  if nb_fields txt = 2 then nth_field txt is
+  else nth_field txt (2 * index_of_sex self_sex + is)
 ;
 
 value uncle_label conf base info x p =
@@ -874,19 +881,19 @@ value print_link_name conf base n p1 p2 sol =
       let sp2 = pp2 <> None in
       if x2 == 0 then
         if sp1 && x1 == 1 then
-          (parent_in_law_label conf ini_p2.sex, False, sp2)
+          (parent_in_law_label conf ini_p1.sex ini_p2.sex, False, sp2)
         else
           let info = ((info, x1), fun r -> r.Consang.lens1) in
           (ancestor_label conf base info x1 p2.sex, sp1, sp2)
       else if x1 == 0 then
         if sp2 && x2 == 1 then
-          (child_in_law_label conf ini_p2.sex, sp1, False)
+          (child_in_law_label conf ini_p2.sex ini_p1.sex, sp1, False)
         else (descendant_label conf base (info, x2) x2 p2, sp1, sp2)
       else if x2 == x1 then
         if x2 == 1 && not (same_parents conf base p2 p1) then
           (half_brother_label conf p2.sex, sp1, sp2)
         else if x2 == 1 && (sp2 || sp1) && p2.sex <> Neuter then
-          (brother_in_law_label conf ini_p2.sex, False, False)
+          (brother_in_law_label conf ini_p2.sex ini_p1.sex, False, False)
         else (brother_label conf x1 p2.sex, sp1, sp2)
       else if x2 == 1 then
         (uncle_label conf base (info, x1) (x1 - x2) p2, sp1, sp2)
@@ -894,7 +901,7 @@ value print_link_name conf base n p1 p2 sol =
       else if x2 < x1 then
         let s =
           let info = ((info, x1), fun r -> r.Consang.lens1) in
-          transl_decline2 conf "%1 of (same or greater generation level) %2"
+          transl_a_of_gr_eq_gen_lev conf
             (brother_label conf x2 p2.sex)
             (ancestor_label conf base info (x1 - x2) Neuter)
         in
@@ -912,20 +919,19 @@ value print_link_name conf base n p1 p2 sol =
               [ [ip2] -> if (pget conf base ip2).sex = Male then sm else sf
               | _ -> sm ]
           in
-          transl_decline2 conf "%1 of (same or greater generation level) %2" d
-            s
+          transl_a_of_gr_eq_gen_lev conf d s
         in
         (s, sp1, sp2)
     in
     let s =
       if sp2 then
-        transl_decline2 conf "%1 of (same or greater generation level) %2"
+        transl_a_of_gr_eq_gen_lev conf
           (transl_nth conf "the spouse" (index_of_sex p2.sex)) s
       else s
     in
     let s =
       if sp1 then
-        transl_decline2 conf "%1 of (same or greater generation level) %2" s
+        transl_a_of_gr_eq_gen_lev conf s
           (transl_nth conf "the spouse" (1 - index_of_sex p1.sex))
       else s
     in
@@ -935,10 +941,8 @@ value print_link_name conf base n p1 p2 sol =
       else gen_person_title_text no_reference raw_access conf base p1
     in
     let s =
-      if x2 < x1 then transl_decline2 conf "%1 of %2" s1 s2
-      else
-        transl_decline2 conf "%1 of (same or greater generation level) %2" s1
-          s2
+      if x2 < x1 then transl_a_of_b conf s1 s2
+      else transl_a_of_gr_eq_gen_lev conf s1 s2
     in
     Wserver.wprint "%s.\n" (nominative s)
   }
@@ -1071,31 +1075,23 @@ value print_solution_not_ancestor conf base long p1 p2 sol =
       [ [(a, _)] -> ancestor_label conf base info x a.sex
       | _ -> parents_label conf base info x ]
     in
+    let print pp p alab =
+      let s = gen_person_title_text no_reference raw_access conf base p in
+      let s =
+        if pp = None then transl_a_of_b conf alab s
+        else
+          transl_a_of_gr_eq_gen_lev conf
+            (transl_a_of_b conf alab
+               (transl_nth conf "the spouse" (1 - index_of_sex p.sex)))
+            s
+      in
+      Wserver.wprint "%s\n" (nominative s)
+    in
     tag "ul" begin
       html_li conf;
-      let s = gen_person_title_text no_reference raw_access conf base p1 in
-      let s =
-        if pp1 = None then s
-        else
-          transl_decline2 conf "%1 of (same or greater generation level) %2"
-            (transl_nth conf "the spouse" (1 - index_of_sex p1.sex)) s
-      in
-      let s =
-        transl_decline2 conf "%1 of %2" (lab (fun r -> r.Consang.lens1) x1) s
-      in
-      Wserver.wprint "%s\n" (nominative s);
+      print pp1 p1 (lab (fun r -> r.Consang.lens1) x1);
       html_li conf;
-      let s = gen_person_title_text no_reference raw_access conf base p2 in
-      let s =
-        if pp2 = None then s
-        else
-          transl_decline2 conf "%1 of (same or greater generation level) %2"
-            (transl_nth conf "the spouse" (1 - index_of_sex p2.sex)) s
-      in
-      let s =
-        transl_decline2 conf "%1 of %2" (lab (fun r -> r.Consang.lens2) x2) s
-      in
-      Wserver.wprint "%s\n" (nominative s);
+      print pp2 p2 (lab (fun r -> r.Consang.lens2) x2);
     end;
     Wserver.wprint "</ul>\n"
   }
@@ -1230,7 +1226,7 @@ value print_propose_upto conf base p1 p2 rl =
         Wserver.wprint "<font size=-1>";
         Wserver.wprint "%s"
           (capitale
-             (transl_decline2 conf "%1 of %2" (transl conf "ancestors")
+             (transl_a_of_b conf (transl conf "ancestors")
                 (person_title_text conf base p)));
         Wserver.wprint " %s"
           (transl_decline conf "up to" (person_title_text conf base a));
@@ -1511,16 +1507,17 @@ value print_main_relationship conf base long p1 p2 rel =
             (transl_nth conf "relationship link/relationship links"
                (if Num.eq total Num.one then 0 else 1));
           if long then () else print_dag_links conf base p1 p2 rl;
-          if not all_by_marr && age_autorise conf base p1 &&
-             age_autorise conf base p2 && a1.consang != Adef.fix (-1) &&
+          if not all_by_marr && authorized_age conf base p1 &&
+             authorized_age conf base p2 && a1.consang != Adef.fix (-1) &&
              a2.consang != Adef.fix (-1)
           then do {
             html_p conf;
             Wserver.wprint "<em>%s: " (capitale (transl conf "relationship"));
-            print_decimal_num conf
-              (round_2_dec
-                 (Adef.float_of_fix (Adef.fix_of_float relationship) *.
-                    100.0));
+            Wserver.wprint "%s"
+              (string_of_decimal_num conf
+                 (round_2_dec
+                    (Adef.float_of_fix (Adef.fix_of_float relationship) *.
+                       100.0)));
             Wserver.wprint "%%</em>";
             html_p conf
           }
