@@ -1,5 +1,5 @@
 (* camlp4r ./pa_lock.cmo ./pa_html.cmo pa_extend.cmo *)
-(* $Id: srcfile.ml,v 4.11 2002/02/26 17:49:04 ddr Exp $ *)
+(* $Id: srcfile.ml,v 4.16 2002/12/19 22:54:31 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Config;
@@ -15,10 +15,9 @@ type counter =
     normal_cnt : mutable int }
 ;
 
-value get_date () =
-  let tm = Unix.localtime (Unix.time ()) in
-  Printf.sprintf "%02d/%02d/%d" tm.Unix.tm_mday (succ tm.Unix.tm_mon)
-    (tm.Unix.tm_year + 1900)
+value get_date conf =
+  Printf.sprintf "%02d/%02d/%d" conf.today.day conf.today.month
+    conf.today.year
 ;
 
 value adm_file f =
@@ -46,12 +45,12 @@ value count conf =
         {welcome_cnt = wc; request_cnt = rc; start_date = d; wizard_cnt = wzc;
          friend_cnt = frc; normal_cnt = nrc}
       with _ ->
-        {welcome_cnt = 0; request_cnt = 0; start_date = get_date ();
+        {welcome_cnt = 0; request_cnt = 0; start_date = get_date conf;
          wizard_cnt = 0; friend_cnt = 0; normal_cnt = 0}
     in
     do { close_in ic; rd }
   with _ ->
-    {welcome_cnt = 0; request_cnt = 0; start_date = get_date ();
+    {welcome_cnt = 0; request_cnt = 0; start_date = get_date conf;
      wizard_cnt = 0; friend_cnt = 0; normal_cnt = 0}
 ;
 
@@ -78,55 +77,6 @@ value write_counter conf r =
     ()
 ;
 
-value std_date () =
-  let tm = Unix.localtime (Unix.time ()) in
-  Printf.sprintf "%04d-%02d-%02d %02d:%02d:%02d" (tm.Unix.tm_year + 1900)
-    (succ tm.Unix.tm_mon) tm.Unix.tm_mday tm.Unix.tm_hour tm.Unix.tm_min
-    tm.Unix.tm_sec
-;
-
-value read_wf_trace fname =
-  match try Some (open_in fname) with [ Sys_error _ -> None ] with
-  [ Some ic ->
-      let r = ref [] in
-      do {
-        try while True do { r.val := [input_line ic :: r.val] } with
-        [ End_of_file -> close_in ic ];
-        List.rev r.val
-      }
-  | None -> [] ]
-;
-
-value write_wf_trace fname wt =
-  let oc = open_out fname in
-  do {
-    List.iter (fun (dt, u) -> Printf.fprintf oc "%s %s\n" dt u) wt;
-    close_out oc;
-  }
-;
-
-value update_wf_trace conf fname =
-  let dt = std_date () in
-  let wt =
-    let r = read_wf_trace fname in
-    let dtlen = String.length dt in
-    let rec loop found r =
-      fun
-      [ [x :: l] ->
-          if String.length x > dtlen + 2 then
-            let u =
-              String.sub x (dtlen + 1) (String.length x - dtlen - 1)
-            in
-            if u = conf.user then loop True [(dt, u) :: r] l
-            else loop found [(String.sub x 0 dtlen, u) :: r] l
-          else loop found r l
-      | [] -> if found then r else [(dt, conf.user) :: r] ]
-    in
-    loop False [] r
-  in
-  write_wf_trace fname (Sort.list \> wt)
-;
-
 value set_wizard_and_friend_traces conf =
   if conf.wizard && conf.user <> "" then
     let wpf =
@@ -193,16 +143,16 @@ value lang_file_name conf fname =
   in
   if Sys.file_exists fname1 then fname1
   else
-    List.fold_right Filename.concat [Util.lang_dir.val; "lang"; conf.lang]
-      (Filename.basename fname ^ ".txt")
+    search_in_lang_path
+      (Filename.concat conf.lang (Filename.basename fname ^ ".txt"))
 ;
 
 value any_lang_file_name fname =
   let fname1 = Util.base_path ["lang"] (Filename.basename fname ^ ".txt") in
   if Sys.file_exists fname1 then fname1
   else
-    List.fold_right Filename.concat [Util.lang_dir.val; "lang"]
-      (Filename.basename fname ^ ".txt")
+    search_in_lang_path
+      (Filename.concat "lang" (Filename.basename fname ^ ".txt"))
 ;
 
 value source_file_name conf fname =
@@ -389,22 +339,6 @@ value src_translate conf base nomin ic =
   else lexicon_translate conf base nomin ic c
 ;
 
-value language_name conf lang =
-  let str = transl conf " !languages" in
-  let len = String.length lang in
-  let rec loop beg i =
-    if i == String.length str && i == beg then lang
-    else if i == String.length str || str.[i] == '/' then
-      if i > beg + len + 1 && str.[beg + len] = '=' &&
-         String.sub str beg len = lang then
-        String.sub str (beg + len + 1) (i - beg - len - 1)
-      else if i == String.length str then lang
-      else loop (i + 1) (i + 1)
-    else loop beg (i + 1)
-  in
-  loop 0 0
-;
-
 value browser_cannot_handle_passwords conf =
   let user_agent = Wserver.extract_param "user-agent: " '/' conf.request in
   String.lowercase user_agent = "konqueror"
@@ -440,6 +374,11 @@ value rec copy_from_channel conf base ic mode =
     | 'j' -> conf.just_friend_wizard
     | 'l' -> no_tables
     | 'n' -> base.data.bnotes.nread 1 <> ""
+    | 'o' -> Sys.file_exists (Wiznotes.dir conf)
+    | 'p' ->
+        match p_getenv conf.base_env (get_variable ic) with
+        [ Some "" | None -> False
+        | Some _ -> True ]
     | 's' -> p_getenv conf.base_env (get_variable ic) <> Some "no"
     | 'w' -> conf.wizard
     | 'z' -> Util.find_person_in_env conf base "z" <> None
@@ -494,7 +433,8 @@ value rec copy_from_channel conf base ic mode =
                   let c = input_char ic in
                   if c = ';' then Buff.get len else loop (Buff.store len c)
               in
-              Wserver.wprint "%s" (language_name conf lang)
+              let lang_def = transl conf " !languages" in
+              Wserver.wprint "%s" (Translate.language_name lang lang_def)
           | 'V' ->
               match p_getenv conf.base_env (get_variable ic) with
               [ Some txt -> Wserver.wprint "%s" txt
@@ -567,9 +507,7 @@ value print_start conf base =
 
 value print_lexicon conf base =
   let title _ = Wserver.wprint "Lexicon" in
-  let fname =
-    List.fold_right Filename.concat [Util.lang_dir.val; "lang"] "lexicon.txt"
-  in
+  let fname = search_in_lang_path (Filename.concat "lang" "lexicon.txt") in
   do {
     Util.header conf title;
     match try Some (open_in fname) with [ Sys_error _ -> None ] with
