@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo *)
-(* $Id: templ.ml,v 4.12 2002/02/14 10:19:41 ddr Exp $ *)
+(* $Id: templ.ml,v 4.15 2002/12/09 05:09:54 ddr Exp $ *)
 
 open Config;
 open Util;
@@ -305,7 +305,7 @@ value parse_templ conf strm =
 
 value open_templ conf dir name =
   let std_fname =
-    List.fold_right Filename.concat [lang_dir.val; "etc"] (name ^ ".txt")
+    search_in_lang_path (Filename.concat "etc" (name ^ ".txt"))
   in
   if dir = "" then try Some (open_in std_fname) with [ Sys_error _ -> None ]
   else
@@ -443,32 +443,47 @@ value rec skip_spaces_and_newlines s i =
     | _ -> i ]
 ;
 
-value eval_transl conf upp s c =
+value eval_transl_lexicon conf upp s c =
   let r =
     match try Some (int_of_string c) with [ Failure _ -> None ] with
     [ Some n ->
         match split_at_coloncolon s with
         [ None -> Gutil.nominative (Util.transl_nth conf s n)
         | Some (s1, s2) ->
-            let s2 =
-              try
-                if String.length s2 > 0 && s2.[0] = '|' then
-                  let i = 1 in
-                  let j = String.rindex s2 '|' in
-                  let k = skip_spaces_and_newlines s2 (j + 1) in
-                  let s3 = String.sub s2 i (j - i) in
-                  let s4 = String.sub s2 k (String.length s2 - k) in
-                  s3 ^ Util.transl_nth conf s4 n
-                else raise Not_found
-              with
-              [ Not_found -> Util.transl_nth conf s2 n ]
-            in
-            Util.transl_decline conf s1 s2 ]
+            try
+              if String.length s2 > 0 && s2.[0] = '|' then
+                let i = 1 in
+                let j = String.rindex s2 '|' in
+                let k = skip_spaces_and_newlines s2 (j + 1) in
+                let s3 = String.sub s2 i (j - i) in
+                let s4 = String.sub s2 k (String.length s2 - k) in
+                let s2 = s3 ^ Util.transl_nth conf s4 n in
+                Util.transl_decline conf s1 s2
+              else if String.length s2 > 0 && s2.[0] = ':' then
+                let s2 = String.sub s2 1 (String.length s2 - 1) in
+                Printf.sprintf
+                  (Util.ftransl_nth conf (Util.valid_format "%t" s1) n)
+                     (fun _ -> s2)
+              else raise Not_found
+            with
+            [ Not_found ->
+                Util.transl_decline conf s1 (Util.transl_nth conf s2 n) ] ]
     | None -> Gutil.nominative (Util.transl conf s) ^ c ]
   in
   if upp then capitale r else r
 ;
 
+value eval_transl_inline conf s =
+  Translate.inline conf.lang '%' (fun c -> "%" ^ String.make 1 c) s
+;
+
+value eval_transl conf upp s c =
+  if c = "" && String.length s > 0 && s.[0] = '\n' then
+    eval_transl_inline conf s
+  else
+    eval_transl_lexicon conf upp s c
+;
+
 value eval_date_field =
   fun
   [ Some d ->
