@@ -1,5 +1,5 @@
 (* camlp4r ./pa_html.cmo *)
-(* $Id: update.ml,v 4.20 2002/03/06 12:21:23 ddr Exp $ *)
+(* $Id: update.ml,v 4.25 2002/10/26 01:22:43 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Config;
@@ -8,7 +8,7 @@ open Gutil;
 open Util;
 
 exception ModErr;
-type create_info = (option date * string * option date * string);
+type create_info = (option date * string * death * option date * string);
 type create = [ Create of sex and option create_info | Link ];
 type key = (string * string * int * create * string);
 
@@ -31,7 +31,7 @@ value has_children base u =
 value infer_death conf birth =
   match birth with
   [ Some (Dgreg d _) ->
-      let a = Gutil.annee (Gutil.temps_ecoule d conf.today) in
+      let a = Gutil.year_of (Gutil.time_gone_by d conf.today) in
       if a > 120 then DeadDontKnowWhen
       else if a <= 80 then NotDead
       else DontKnowIfDead
@@ -222,7 +222,7 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base p;
-             Date.afficher_dates_courtes conf base p
+             Wserver.wprint "%s" (Date.short_dates_text conf base p)
            })
   | IncoherentSex p _ _ ->
       Wserver.wprint
@@ -252,7 +252,7 @@ value print_warning conf base =
                  html_li conf;
                  if p.surname = fath.surname then print_first_name conf base p
                  else print_someone conf base p;
-                 Date.afficher_dates_courtes conf base p;
+                 Wserver.wprint "%s" (Date.short_dates_text conf base p);
                  Wserver.wprint "\n"
                })
             before;
@@ -269,7 +269,7 @@ value print_warning conf base =
                  if p.surname = fath.surname then
                    print_first_name_ref conf base p
                  else print_someone_ref conf base p;
-                 Date.afficher_dates_courtes conf base p;
+                 Wserver.wprint "%s" (Date.short_dates_text conf base p);
                  Wserver.wprint "\n"
                })
             des.children;
@@ -289,11 +289,11 @@ value print_warning conf base =
         Wserver.wprint "<ul>\n";
         html_li conf;
         print_first_name_strong conf base elder;
-        Date.afficher_dates_courtes conf base elder;
+        Wserver.wprint "%s" (Date.short_dates_text conf base elder);
         Wserver.wprint "\n";
         html_li conf;
         print_first_name_strong conf base x;
-        Date.afficher_dates_courtes conf base x;
+        Wserver.wprint "%s" (Date.short_dates_text conf base x);
         Wserver.wprint "</ul>"
       }
   | DeadTooEarlyToBeFather father child ->
@@ -303,12 +303,12 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base child;
-             Date.afficher_dates_courtes conf base child
+             Wserver.wprint "%s" (Date.short_dates_text conf base child)
            })
         (fun _ ->
            do {
              print_someone_strong conf base father;
-             Date.afficher_dates_courtes conf base father
+             Wserver.wprint "%s" (Date.short_dates_text conf base father)
            })
   | MarriageDateAfterDeath p ->
       Wserver.wprint
@@ -316,7 +316,7 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base p;
-             Date.afficher_dates_courtes conf base p
+             Wserver.wprint "%s" (Date.short_dates_text conf base p)
            })
   | MarriageDateBeforeBirth p ->
       Wserver.wprint
@@ -324,7 +324,7 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base p;
-             Date.afficher_dates_courtes conf base p
+             Wserver.wprint "%s" (Date.short_dates_text conf base p)
            })
   | MotherDeadAfterChildBirth mother child ->
       Wserver.wprint
@@ -332,12 +332,12 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base child;
-             Date.afficher_dates_courtes conf base child
+             Wserver.wprint "%s" (Date.short_dates_text conf base child)
            })
         (fun _ ->
            do {
              print_someone_strong conf base mother;
-             Date.afficher_dates_courtes conf base mother
+             Wserver.wprint "%s" (Date.short_dates_text conf base mother)
            })
   | ParentBornAfterChild p c ->
       do {
@@ -349,9 +349,7 @@ value print_warning conf base =
       do {
         print_someone_strong conf base p;
         Wserver.wprint "\n%s\n" (transl conf "is a very young parent");
-        Wserver.wprint "(";
-        Date.print_age conf a;
-        Wserver.wprint ")"
+        Wserver.wprint "(%s)" (Date.string_of_age conf a);
       }
   | TitleDatesError p t ->
       Wserver.wprint
@@ -359,7 +357,7 @@ value print_warning conf base =
         (fun _ ->
            do {
              print_someone_strong conf base p;
-             Date.afficher_dates_courtes conf base p
+             Wserver.wprint "%s" (Date.short_dates_text conf base p)
            })
         (fun _ ->
            Wserver.wprint "<strong>%s %s</strong> <em>%s-%s</em>"
@@ -378,7 +376,7 @@ value print_warning conf base =
         print_someone_strong conf base p;
         Wserver.wprint "\n";
         Wserver.wprint (ftransl conf "married at age %t")
-          (fun _ -> Date.print_age conf a)
+          (fun _ -> Wserver.wprint "%s" (Date.string_of_age conf a))
       } ]
 ;
 
@@ -464,11 +462,29 @@ value bad_date conf d =
   }
 ;
 
+value int_of_field s =
+  try Some (int_of_string (strip_spaces s)) with [ Failure _ -> None ]
+;
+
 value reconstitute_date_dmy conf var =
-  match get_number var "yyyy" conf.env with
+  let (prec, y) =
+    let y = get var "yyyy" conf.env in
+    let prec = p_getenv conf.env (var ^ "_prec") in
+    let len = String.length y in
+    if len > 1 then
+      match (y.[0], y.[len-1]) with
+      [ ('?', _) -> (Some "maybe", String.sub y 1 (len - 1))
+      | ('/', '/') -> (Some "about", String.sub y 1 (len - 2))
+      | ('<', _) | ('/', _) -> (Some "before", String.sub y 1 (len - 1))
+      | ('>', _) -> (Some "after", String.sub y 1 (len - 1))
+      | (_, '/') -> (Some "after", String.sub y 0 (len - 1))
+      | _ -> (prec, y) ]
+    else (prec, y)
+  in
+  match int_of_field y with
   [ Some y ->
       let prec =
-        match p_getenv conf.env (var ^ "_prec") with
+        match prec with
         [ Some "about" -> About
         | Some "maybe" -> Maybe
         | Some "before" -> Before
@@ -505,7 +521,7 @@ value reconstitute_date_dmy conf var =
 ;
 
 value check_greg_day conf d =
-  if d.day > nb_jours_dans_mois d.month d.year then bad_date conf d else ()
+  if d.day > nb_days_in_month d.month d.year then bad_date conf d else ()
 ;
 
 value reconstitute_date conf var =
@@ -762,14 +778,17 @@ value insert_person conf base src new_persons (f, s, o, create, var) =
           let empty_string = insert_string base "" in
           let (birth, birth_place) =
             match info with
-            [ Some (b, bpl, _, _) -> (b, bpl)
+            [ Some (b, bpl, _, _, _) -> (b, bpl)
             | None -> (None, "") ]
           in
           let (death, death_place) =
             match info with
-            [ Some (_, _, Some d, dpl) ->
+            [ Some (_, _, _, Some d, dpl) ->
                 (Death Unspecified (Adef.cdate_of_date d), dpl)
-            | Some (_, _, None, dpl) when dpl <> "" -> (DeadDontKnowWhen, dpl)
+            | Some (_, _, _, None, dpl) when dpl <> "" ->
+                (DeadDontKnowWhen, dpl)
+            | Some (_, _, (DeadDontKnowWhen | NotDead as dead), None, dpl) ->
+                (dead, dpl)
             | _ -> (infer_death conf birth, "") ]
           in
           let p =
