@@ -1,5 +1,5 @@
 (* camlp4r ./pa_lock.cmo ./pa_html.cmo *)
-(* $Id: updateFamOk.ml,v 4.16 2002/03/05 16:29:58 ddr Exp $ *)
+(* $Id: updateFamOk.ml,v 4.21 2002/11/06 12:16:38 ddr Exp $ *)
 (* Copyright (c) 2001 INRIA *)
 
 open Config;
@@ -26,30 +26,42 @@ value getn conf var key =
 ;
 
 value reconstitute_somebody conf var =
-  let first_name = strip_spaces (getn conf var "fn") in
-  let surname = strip_spaces (getn conf var "sn") in
+  let first_name = only_printable (getn conf var "fn") in
+  let surname = only_printable (getn conf var "sn") in
   let occ = try int_of_string (getn conf var "occ") with [ Failure _ -> 0 ] in
+  let sex =
+    match p_getenv conf.env (var ^ "_sex") with
+    [ Some "M" -> Male
+    | Some "F" -> Female
+    | _ -> Neuter ]
+  in
   let create =
     match getn conf var "p" with
-    [ "create" -> Update.Create Neuter None
+    [ "create" -> Update.Create sex None
     | _ -> Update.Link ]
   in
   (first_name, surname, occ, create, var)
 ;
 
 value reconstitute_parent_or_child conf var default_surname =
-  let first_name = getn conf var "fn" in
+  let first_name = only_printable (getn conf var "fn") in
   let surname =
-    let surname = getn conf var "sn" in
+    let surname = only_printable (getn conf var "sn") in
     if surname = "" then default_surname else surname
   in
   let occ = try int_of_string (getn conf var "occ") with [ Failure _ -> 0 ] in
   let create_info =
     let b = Update.reconstitute_date conf (var ^ "b") in
     let bpl = getn conf (var ^ "b") "pl" in
+    let death =
+      match p_getenv conf.env (var ^ "d_yyyy") with
+      [ Some "+" -> DeadDontKnowWhen
+      | Some ("-" | "=") -> NotDead
+      | _ -> DontKnowIfDead ]
+    in
     let d = Update.reconstitute_date conf (var ^ "d") in
     let dpl = getn conf (var ^ "d") "pl" in
-    (b, bpl, d, dpl)
+    (b, bpl, death, d, dpl)
   in
   let sex =
     match p_getenv conf.env (var ^ "_sex") with
@@ -188,7 +200,7 @@ value print_err_parents conf base p =
     rheader conf title;
     Wserver.wprint "\n";
     Wserver.wprint (fcapitale (ftransl conf "%t already has parents"))
-      (fun _ -> afficher_personne_referencee conf base p);
+      (fun _ -> Wserver.wprint "\n%s" (referenced_person_text conf base p));
     Wserver.wprint "\n";
     html_p conf;
     tag "ul" begin
@@ -207,7 +219,7 @@ value print_err_father_sex conf base p =
   let title _ = Wserver.wprint "%s" (capitale (transl conf "error")) in
   do {
     rheader conf title;
-    afficher_personne_referencee conf base p;
+    Wserver.wprint "\n%s" (referenced_person_text conf base p);
     Wserver.wprint "\n%s\n" (transl conf "should be male");
     Update.print_return conf;
     trailer conf;
@@ -219,7 +231,7 @@ value print_err_mother_sex conf base p =
   let title _ = Wserver.wprint "%s" (capitale (transl conf "error")) in
   do {
     rheader conf title;
-    afficher_personne_referencee conf base p;
+    Wserver.wprint "\n%s" (referenced_person_text conf base p);
     Wserver.wprint "\n%s\n" (transl conf "should be female");
     Update.print_return conf;
     trailer conf;
@@ -612,10 +624,12 @@ value print_family conf base wl cpl des =
     | None -> () ];
     Wserver.wprint "<ul>\n";
     html_li conf;
-    afficher_personne_referencee conf base (poi base cpl.father);
+    Wserver.wprint "\n%s"
+      (referenced_person_text conf base (poi base cpl.father));
     Wserver.wprint "\n";
     html_li conf;
-    afficher_personne_referencee conf base (poi base cpl.mother);
+    Wserver.wprint "\n%s"
+      (referenced_person_text conf base (poi base cpl.mother));
     Wserver.wprint "</ul>\n";
     if des.children <> [| |] then do {
       html_p conf;
@@ -624,7 +638,8 @@ value print_family conf base wl cpl des =
         (fun ip ->
            do {
              html_li conf;
-             afficher_personne_referencee conf base (poi base ip);
+             Wserver.wprint "\n%s"
+               (referenced_person_text conf base (poi base ip));
              Wserver.wprint "\n"
            })
         des.children;
@@ -685,7 +700,7 @@ value print_inv_ok conf base p =
   do {
     header conf title;
     print_link_to_welcome conf True;
-    afficher_personne_referencee conf base p;
+    Wserver.wprint "\n%s" (referenced_person_text conf base p);
     Wserver.wprint "\n";
     trailer conf
   }
