@@ -1,17 +1,43 @@
 (* camlp4r ./pa_lock.cmo *)
-(* $Id: util.ml,v 4.41 2002/03/06 12:21:25 ddr Exp $ *)
+(* $Id: util.ml,v 4.70 2002/12/30 18:40:05 ddr Exp $ *)
 (* Copyright (c) 2002 INRIA *)
 
 open Def;
 open Config;
 open Gutil;
 
-value lang_dir = ref Filename.current_dir_name;
+value open_in fname =
+  if String.contains fname '\000' then raise (Sys_error "")
+  else Pervasives.open_in fname
+;
+
+value open_in_bin fname =
+  if String.contains fname '\000' then raise (Sys_error "")
+  else Pervasives.open_in_bin fname
+;
+
+value sharelib =
+  List.fold_right Filename.concat [Gwlib.prefix; "share"] "geneweb"
+;
+
+value lang_path = ref [Filename.current_dir_name; sharelib];
+value doc_path = ref [];
 value base_dir = ref Filename.current_dir_name;
-value doc_dir = ref "";
 value cnt_dir = ref "";
 value images_url = ref "";
 
+value search_in_path p s =
+  loop p.val where rec loop =
+    fun
+    [ [d :: dl] ->
+        let f = Filename.concat d s in
+        if Sys.file_exists f then f else loop dl
+    | [] -> s ]
+;
+
+value search_in_lang_path = search_in_path lang_path;
+value search_in_doc_path = search_in_path doc_path;
+
 (* Internationalization *)
 
 value start_with_vowel s =
@@ -58,6 +84,10 @@ value rec capitale s =
     | _ -> s ]
 ;
 
+ifdef OCAML_307 then
+value fcapitale (a : format 'a 'b 'c 'd) : format 'a 'b 'c 'd =
+  Obj.magic capitale a
+else
 value fcapitale (a : format 'a 'b 'c) : format 'a 'b 'c =
   Obj.magic capitale a
 ;
@@ -138,7 +168,7 @@ value gen_decline conf wt s =
 
 value transl_decline conf w s = gen_decline conf (transl conf w) s;
 
-value gen_decline2 conf wt s1 s2 =
+value gen_decline2 wt s1 s2 =
   let string_of =
     fun
     [ '1' -> Some s1
@@ -153,7 +183,7 @@ value gen_decline2 conf wt s1 s2 =
         match wt.[i] with
         [ '%' when i + 1 < len ->
             match string_of wt.[i + 1] with
-            [ Some s -> (s, i + 1)
+            [ Some s -> (nominative s, i + 1)
             | None -> ("%", i) ]
         | ':' when i + 4 < len && wt.[i + 2] = ':' && wt.[i + 3] = '%' ->
             let c = wt.[i + 1] in
@@ -166,6 +196,7 @@ value gen_decline2 conf wt s1 s2 =
               if j + 2 < len && wt.[j + 1] = '%' then
                 match string_of wt.[j + 2] with
                 [ Some s ->
+                    let s = nominative s in
                     let s =
                       if start_with_vowel s then String.make 1 wt.[j - 1] ^ s
                       else String.sub wt (i + 1) (j - i - 2) ^ " " ^ s
@@ -182,12 +213,23 @@ value gen_decline2 conf wt s1 s2 =
   loop 0
 ;
 
-value transl_decline2 conf w s1 s2 = gen_decline2 conf (transl conf w) s1 s2;
+value transl_a_of_b conf = gen_decline2 (transl_nth conf "%1 of %2" 0);
+value transl_a_of_gr_eq_gen_lev conf =
+  gen_decline2 (transl_nth conf "%1 of %2" 1)
+;
 
+ifdef OCAML_307 then
+value failed_format s : format 'a 'b 'c 'd = Obj.magic ("[" ^ s ^ "]")
+else
 value failed_format s : format 'a 'b 'c = Obj.magic ("[" ^ s ^ "]");
 
-value valid_format (ini_fmt : format 'a 'b 'c) (r : string) =
-  let s : string = Obj.magic ini_fmt in
+value valid_format ini_fmt (r : string) =
+  let s : string =
+    ifdef OCAML_307 then
+      Obj.magic (ini_fmt : format 'a 'b 'c 'd)
+    else
+      Obj.magic (ini_fmt : format 'a 'b 'c)
+  in
   let rec loop i j =
     if i < String.length s - 1 && j < String.length r - 1 then
       match (s.[i], s.[i + 1], r.[j], r.[j + 1]) with
@@ -200,7 +242,11 @@ value valid_format (ini_fmt : format 'a 'b 'c) (r : string) =
       if s.[i] == '%' then failed_format s else loop (i + 1) j
     else if j < String.length r - 1 then
       if r.[j] == '%' then failed_format s else loop i (j + 1)
-    else (Obj.magic r : format 'a 'b 'c)
+    else
+      ifdef OCAML_307 then
+        (Obj.magic r : format 'a 'b 'c 'd)
+      else
+        (Obj.magic r : format 'a 'b 'c)
   in
   loop 0 0
 ;
@@ -304,13 +350,6 @@ value html conf =
     Wserver.wprint "Date: %s" (string_of_ctime conf); nl ();
     Wserver.wprint "Connection: close"; nl ();
     Wserver.wprint "Content-type: text/html; charset=%s" charset; nl ();
-    match conf.set_cookie with
-    [ Some (k, v) ->
-        do {
-          Wserver.wprint "Set-cookie: %s=%s" k v;
-          nl ()
-        }
-    | None -> () ];
   }
 ;
 
@@ -410,7 +449,9 @@ value p_getenv env label =
 
 value p_getint env label =
   match p_getenv env label with
-  [ Some s -> try Some (int_of_string (strip_spaces s)) with _ -> None
+  [ Some s ->
+      try Some (int_of_string (strip_spaces s)) with
+      [ Failure _ -> None ]
   | None -> None ]
 ;
 
@@ -426,7 +467,7 @@ value parent_has_title base p =
   | _ -> False ]
 ;
 
-value age_autorise conf base p =
+value authorized_age conf base p =
   if p.access = Public || conf.friend || conf.wizard then True
   else if
     conf.public_if_titles && p.access = IfTitles &&
@@ -439,11 +480,13 @@ value age_autorise conf base p =
     with
     [ (_, _, NotDead, _) when conf.private_years > 0 -> False
     | (Some (Dgreg d _), _, _, _) ->
-        let a = temps_ecoule d conf.today in a.year > conf.private_years
+        let a = time_gone_by d conf.today in a.year > conf.private_years
     | (_, Some (Dgreg d _), _, _) ->
-        let a = temps_ecoule d conf.today in a.year > conf.private_years
+        let a = time_gone_by d conf.today in a.year > conf.private_years
     | (_, _, _, Some (Dgreg d _)) ->
-        let a = temps_ecoule d conf.today in a.year > conf.private_years
+        let a = time_gone_by d conf.today in a.year > conf.private_years
+    | (None, None, DontKnowIfDead, None) ->
+        p.access <> Private && conf.public_if_no_date
     | _ ->
         let u = uoi base p.cle_index in
         let rec loop i =
@@ -452,7 +495,7 @@ value age_autorise conf base p =
             let fam = foi base u.family.(i) in
             match Adef.od_of_codate fam.marriage with
             [ Some (Dgreg d _) ->
-                let a = temps_ecoule d conf.today in
+                let a = time_gone_by d conf.today in
                 a.year > conf.private_years
             | _ -> loop (i + 1) ]
         in
@@ -466,11 +509,13 @@ value is_old_person conf p =
   with
   [ (_, _, NotDead, _) when conf.private_years > 0 -> False
   | (Some (Dgreg d _), _, _, _) ->
-      let a = temps_ecoule d conf.today in a.year > conf.private_years
+      let a = time_gone_by d conf.today in a.year > conf.private_years
   | (_, Some (Dgreg d _), _, _) ->
-      let a = temps_ecoule d conf.today in a.year > conf.private_years
+      let a = time_gone_by d conf.today in a.year > conf.private_years
   | (_, _, _, Some (Dgreg d _)) ->
-      let a = temps_ecoule d conf.today in a.year > conf.private_years
+      let a = time_gone_by d conf.today in a.year > conf.private_years
+  | (None, None, DontKnowIfDead, None) ->
+      p.access <> Private && conf.public_if_no_date
   | _ -> False ]
 ;
 
@@ -562,7 +607,7 @@ value exit_nobr () =
 ;
 *)
 
-value connais base p =
+value know base p =
   sou base p.first_name <> "?" || sou base p.surname <> "?"
 ;
 
@@ -587,12 +632,6 @@ value acces_n conf base n x =
 
 value acces conf base x = acces_n conf base "" x;
 
-value calculer_age conf p =
-  match Adef.od_of_codate p.birth with
-  [ Some (Dgreg d _) -> Some (temps_ecoule d conf.today)
-  | _ -> None ]
-;
-
 type p_access = (base -> person -> string * base -> person -> string);
 value std_access = (p_first_name, p_surname);
 value raw_access =
@@ -647,16 +686,6 @@ value person_text_without_surname =
   gen_person_text_without_surname std_access
 ;
 
-value afficher_nom_titre_reference conf base p s =
-  match p.qualifiers with
-  [ [] ->
-      Wserver.wprint "<a href=\"%s%s\">%s</a>" (commd conf)
-        (acces conf base p) s
-  | [nn :: _] ->
-      Wserver.wprint "<a href=\"%s%s\">%s <em>%s</em></a>" (commd conf)
-        (acces conf base p) s (sou base nn) ]
-;
-
 value main_title base p =
   let rec find_main =
     fun
@@ -724,7 +753,7 @@ value reference conf base p s =
 value no_reference conf base p s = s;
 
 value gen_person_title_text reference p_access conf base p =
-  if age_autorise conf base p then
+  if authorized_age conf base p then
     match main_title base p with
     [ Some t ->
         reference conf base p (titled_person_text conf base p t) ^
@@ -739,6 +768,14 @@ value referenced_person_title_text =
 
 value person_title_text = gen_person_title_text no_reference std_access;
 
+value referenced_person_text conf base p =
+  reference conf base p (person_text conf base p)
+;
+
+value referenced_person_text_without_surname conf base p =
+  reference conf base p (person_text_without_surname conf base p)
+;
+
 value gen_person_text_without_title p_access conf base p =
   match main_title base p with
   [ Some t ->
@@ -755,7 +792,7 @@ value gen_person_text_without_title p_access conf base p =
 value person_text_without_title = gen_person_text_without_title std_access;
 
 value person_title conf base p =
-  if age_autorise conf base p then
+  if authorized_age conf base p then
     match main_title base p with
     [ Some t -> one_title_text conf base p t
     | None -> "" ]
@@ -763,7 +800,7 @@ value person_title conf base p =
 ;
 
 value surname_begin n =
-  let i = initiale n in
+  let i = initial n in
   if i == 0 then ""
   else
     let i =
@@ -774,7 +811,7 @@ value surname_begin n =
 ;
 
 value surname_end n =
-  let i = initiale n in
+  let i = initial n in
   if i == 0 then n else String.sub n i (String.length n - i)
 ;
 
@@ -841,8 +878,8 @@ value base_len n =
 value open_etc_file fname =
   let fname1 = base_path ["etc"] (Filename.basename fname ^ ".txt") in
   let fname2 =
-    List.fold_right Filename.concat [lang_dir.val; "etc"]
-      (Filename.basename fname ^ ".txt")
+    search_in_lang_path
+      (Filename.concat "etc" (Filename.basename fname ^ ".txt"))
   in
   try Some (open_in fname1) with
   [ Sys_error _ -> try Some (open_in fname2) with [ Sys_error _ -> None ] ]
@@ -1175,22 +1212,26 @@ value email_addr s i =
   | None -> None ]
 ;
 
-value dangerous_tags_list =
-  ["applet"; "embed"; "form"; "input"; "object"; "script"]
+value tag_id s i =
+  loop i 0 where rec loop i len =
+    if i = String.length s then Buff.get len
+    else
+      match s.[i] with
+      [ 'a'..'z' | 'A'..'Z' | '0'..'9' as c ->
+          loop (i + 1) (Buff.store len (Char.lowercase s.[i]))
+      | _ -> if len = 0 then loop (i + 1) 0 else Buff.get len ]
 ;
 
-value dangerous_tag s i =
-  let tag_id =
-    loop i 0 where rec loop i len =
-      if i = String.length s then Buff.get len
-      else
-        match s.[i] with
-        [ 'a'..'z' | 'A'..'Z' as c ->
-            loop (i + 1) (Buff.store len (Char.lowercase s.[i]))
-        | _ -> if len = 0 then loop (i + 1) 0 else Buff.get len ]
-  in
-  List.mem tag_id dangerous_tags_list
+value good_tags_list =
+  ["a"; "b"; "br"; "dd"; "div"; "dl"; "dt"; "em"; "font"; "hr"; "h1"; "h2";
+   "h3"; "h4"; "i"; "img"; "li"; "ol"; "p"; "pre"; "strong"; "sup"; "table";
+   "td"; "tr"; "u"; "ul"]
 ;
+value bad_tags_list =
+  ["applet"; "embed"; "form"; "input"; "object"; "script"]
+;
+value good_tag s i = List.mem (tag_id s i) good_tags_list;
+value bad_tag s i = List.mem (tag_id s i) bad_tags_list;
 
 value get_variable s i =
   loop 0 i where rec loop len i =
@@ -1225,17 +1266,18 @@ value expand_env =
    | _ -> s ]
 ;
 
-value copy_string_with_macros conf env s =
+value string_with_macros conf positive_filtering env s =
+  let buff = Buffer.create 1000 in
   loop Out 0 where rec loop tt i =
     if i < String.length s then
       if i + 1 < String.length s && s.[i] = '%' then
         let i =
           try
-            do { Wserver.wprint "%s" (List.assoc s.[i + 1] env ()); i + 2 }
+            do { Buffer.add_string buff (List.assoc s.[i + 1] env ()); i + 2 }
           with
           [ Not_found ->
               match s.[i + 1] with
-              [ 's' -> do { Wserver.wprint "%s" (commd conf); i + 2 }
+              [ 's' -> do { Buffer.add_string buff (commd conf); i + 2 }
               | 'v' ->
                   let (k, j) = get_variable s (i + 2) in
                   let (v, i) =
@@ -1250,33 +1292,39 @@ value copy_string_with_macros conf env s =
                     [ Some v -> (v, j)
                     | None -> ("%", i + 1) ]
                   in
-                  do { Wserver.wprint "%s" v; i }
-              | '%' -> do { Wserver.wprint "%%"; i + 2 }
-              | _ -> do { Wserver.wprint "%%"; i + 1 } ] ]
+                  do { Buffer.add_string buff v; i }
+              | '%' -> do { Buffer.add_string buff "%"; i + 2 }
+              | _ -> do { Buffer.add_string buff "%"; i + 1 } ] ]
         in
         loop tt i
-      else if s.[i] = '<' && dangerous_tag s (i + 1) then do {
-        Wserver.wprint "..."; loop tt (i + 1)
+      else if s.[i] = '<' && i + 1 < String.length s && s.[i+1] = '%' then do {
+        Buffer.add_string buff "<"; loop tt (i + 1)
+      }
+      else if s.[i] = '<' &&
+        (positive_filtering && not (good_tag s (i + 1)) ||
+         not positive_filtering && bad_tag s (i + 1))
+      then do {
+        Buffer.add_string buff "&lt;"; loop tt (i + 1)
       }
       else
         match tt with
         [ In_a_href ->
             let tt = if start_with s i "</a>" then Out else In_a_href in
-            do { Wserver.wprint "%c" s.[i]; loop tt (i + 1) }
+            do { Buffer.add_char buff s.[i]; loop tt (i + 1) }
         | In_norm ->
             let tt = if s.[i] = '>' then Out else In_norm in
-            do { Wserver.wprint "%c" s.[i]; loop tt (i + 1) }
+            do { Buffer.add_char buff s.[i]; loop tt (i + 1) }
         | Out ->
             match http_string s i with
             [ Some j ->
                 let x = String.sub s i (j - i) in
-                do { Wserver.wprint "<a href=%s>%s</a>" x x; loop Out j }
+                do { Printf.bprintf buff "<a href=%s>%s</a>" x x; loop Out j }
             | None ->
                 match email_addr s i with
                 [ Some j ->
                     let x = String.sub s i (j - i) in
                     do {
-                      Wserver.wprint "<a href=\"mailto:%s\">%s</a>" x x;
+                      Printf.bprintf buff "<a href=\"mailto:%s\">%s</a>" x x;
                       loop Out j
                     }
                 | None ->
@@ -1287,8 +1335,8 @@ value copy_string_with_macros conf env s =
                       else if s.[i] = '<' then In_norm
                       else Out
                     in
-                    do { Wserver.wprint "%c" s.[i]; loop tt (i + 1) } ] ] ]
-    else ()
+                    do { Buffer.add_char buff s.[i]; loop tt (i + 1) } ] ] ]
+    else Buffer.contents buff
 ;
 
 value setup_link conf =
@@ -1318,17 +1366,17 @@ value gen_trailer with_logo conf =
     else
       Wserver.wprint "\
 <p>
-<img src=\"%s/gwlogo.gif\"
-alt=... width=64 height=72 align=right>
+<a href=\"%s\"><img src=\"%s/gwlogo.gif\"
+alt=... width=64 height=72 align=right border=0></a>
 <br>
-" (image_prefix conf);
+" (commd conf) (image_prefix conf);
     match open_etc_file "copyr" with
     [ Some ic -> copy_from_etc env conf.lang conf.indep_command ic
     | None ->
         do {
           html_p conf;
           Wserver.wprint "
-<hr><font size=-1><em>(c) Copyright 2002 INRIA -
+<hr><font size=-1><em>(c) Copyright 2003 INRIA -
 GeneWeb %s</em></font>" Version.txt;
           html_br conf;
           ()
@@ -1431,11 +1479,11 @@ value print_parent conf base p fath moth =
   in
   let is = index_of_sex p.sex in
   Wserver.wprint "%s"
-    (transl_decline2 conf "%1 of (same or greater generation level) %2"
+    (transl_a_of_gr_eq_gen_lev conf
        (transl_nth conf "son/daughter/child" is) s)
 ;
 
-value preciser_homonyme conf base p =
+value specify_homonymous conf base p =
   let is = index_of_sex p.sex in
   match (p.public_name, p.qualifiers) with
   [ (n, [nn :: _]) when sou base n <> "" ->
@@ -1480,7 +1528,7 @@ value preciser_homonyme conf base p =
                      else "")
                 in
                 Wserver.wprint "%s"
-                  (transl_decline2 conf "%1 of %2"
+                  (transl_a_of_b conf
                      (transl_nth conf "father/mother" is)
                      (child_fn ^ child_sn))
               else
@@ -1488,7 +1536,7 @@ value preciser_homonyme conf base p =
                 if p_first_name base conjoint <> "?" ||
                    p_surname base conjoint <> "?" then
                   Wserver.wprint "%s"
-                    (transl_decline2 conf "%1 of %2"
+                    (transl_a_of_b conf
                        (transl_nth conf "husband/wife" is)
                        (p_first_name base conjoint ^ " " ^
                           p_surname base conjoint))
@@ -1499,14 +1547,22 @@ value preciser_homonyme conf base p =
       | Some (fath, moth) -> print_parent conf base p fath moth ] ]
 ;
 
-value print_decimal_num conf f =
-  let s = string_of_float f in
+(* fix system bug: string_of_float 17.97 = "17.969999999999" *)
+value my_string_of_float f =
+  Printf.sprintf "%.6g" f
+;
+
+value string_of_decimal_num conf f =
+  let s = my_string_of_float f in
+  let b = Buffer.create 20 in
   let rec loop i =
-    if i == String.length s then ()
+    if i == String.length s then Buffer.contents b
     else do {
       match s.[i] with
-      [ '.' -> Wserver.wprint "%s" (transl conf "(decimal separator)")
-      | x -> Wserver.wprint "%c" x ];
+      [ '.' ->
+          if i == String.length s - 1 then ()
+          else Buffer.add_string b (transl conf "(decimal separator)")
+      | x -> Buffer.add_char b x ];
       loop (i + 1)
     }
   in
@@ -1521,7 +1577,6 @@ value source_image_file_name bname str =
   let fname1 =
     List.fold_right Filename.concat [base_path ["src"] bname; "images"] str
   in
-let _ = do { Printf.eprintf "fname1 %s\n" fname1; flush stderr; } in
   let fname2 =
     List.fold_right Filename.concat [base_dir.val; "src"; "images"] str
   in
@@ -1530,8 +1585,8 @@ let _ = do { Printf.eprintf "fname1 %s\n" fname1; flush stderr; } in
 
 value image_file_name str =
   let fname1 = List.fold_right Filename.concat [base_dir.val; "images"] str in
-  let fname2 = List.fold_right Filename.concat [lang_dir.val; "images"] str in
-  if Sys.file_exists fname1 then fname1 else fname2
+  if Sys.file_exists fname1 then fname1
+  else search_in_lang_path (Filename.concat "images" str)
 ;
 
 value png_image_size ic =
@@ -1611,8 +1666,11 @@ value image_size fname =
   | None -> None ]
 ;
 
-value limited_image_size max_wid max_hei fname =
-  match image_size fname with
+value limited_image_size max_wid max_hei fname size =
+  match
+    if fname = "" then size
+    else image_size fname
+  with
   [ Some (wid, hei) ->
       let (wid, hei) =
         if hei > max_hei then
@@ -1842,35 +1900,49 @@ value auto_image_file conf base p =
 ;
 
 value image_and_size conf base p image_size =
-  if age_autorise conf base p then
+  if not conf.no_image && authorized_age conf base p then
     let image_txt = capitale (transl_nth conf "image/images" 0) in
     match sou base p.image with
     [ "" ->
         match auto_image_file conf base p with
-        [ Some f -> Some (f, Some (image_size f))
+        [ Some f -> Some (True, f, image_size f None)
         | None -> None ]
     | s ->
+        let (s, size) =
+          let l = String.length s - 1 in
+          if s.[l] = ')' then
+            try
+              let pos1 = String.index s '(' in
+              let pos2 = String.index_from s pos1 'x' in
+              let wid = String.sub s (pos1+1) (pos2-pos1-1) in
+              let hei = String.sub s (pos2+1) (l-pos2-1) in
+              let size = Some (int_of_string wid, int_of_string hei) in
+              (String.sub s 0 pos1, image_size "" size)
+            with
+            [ Not_found | Failure _ -> (s, None) ]
+          else (s, None)
+        in
         let http = "http://" in
         if String.length s > String.length http &&
            String.sub s 0 (String.length http) = http then
-          Some (s, None)
+          Some (False, s, size)
         else if Filename.is_implicit s then
           match
             try Some (List.assoc "images_path" conf.base_env) with
             [ Not_found -> None ]
           with
-          [ Some p when p <> "" -> Some (p ^ s, None)
+          [ Some p when p <> "" -> Some (False, p ^ s, size)
           | _ ->
               let fname = personal_image_file_name conf.bname s in
               if Sys.file_exists fname then
-                Some (fname, Some (image_size fname))
+                Some (True, fname, image_size fname None)
               else None ]
         else None ]
   else None
 ;
 
 value has_image conf base p =
-  if age_autorise conf base p then
+  if not conf.no_image && authorized_age conf base p then
     p.image <> Adef.istr_of_int 0 || auto_image_file conf base p <> None
   else False
 ;
@@ -2042,6 +2114,58 @@ value escache_value conf =
   string_of_int v
 ;
 
+value adm_file f =
+  List.fold_right Filename.concat [cnt_dir.val; "cnt"] f
+;
+
+value std_date conf =
+  let (hour, min, sec) = conf.time in
+  Printf.sprintf "%04d-%02d-%02d %02d:%02d:%02d" conf.today.year
+    conf.today.month conf.today.day hour min sec
+;
+
+value read_wf_trace fname =
+  match try Some (open_in fname) with [ Sys_error _ -> None ] with
+  [ Some ic ->
+      let r = ref [] in
+      do {
+        try while True do { r.val := [input_line ic :: r.val] } with
+        [ End_of_file -> close_in ic ];
+        List.rev r.val
+      }
+  | None -> [] ]
+;
+
+value write_wf_trace fname wt =
+  let oc = open_out fname in
+  do {
+    List.iter (fun (dt, u) -> Printf.fprintf oc "%s %s\n" dt u) wt;
+    close_out oc;
+  }
+;
+
+value update_wf_trace conf fname =
+  let dt = std_date conf in
+  let wt =
+    let r = read_wf_trace fname in
+    let dtlen = String.length dt in
+    let rec loop found r =
+      fun
+      [ [x :: l] ->
+          if String.length x > dtlen + 2 then
+            let u =
+              String.sub x (dtlen + 1) (String.length x - dtlen - 1)
+            in
+            if u = conf.user then loop True [(dt, u) :: r] l
+            else loop found [(String.sub x 0 dtlen, u) :: r] l
+          else loop found r l
+      | [] -> if found then r else [(dt, conf.user) :: r] ]
+    in
+    loop False [] r
+  in
+  write_wf_trace fname (Sort.list \> wt)
+;
+
 value commit_patches conf base =
   do {
     base.func.commit_patches ();
@@ -2051,32 +2175,55 @@ value commit_patches conf base =
            if k = "escache" then (k, escache_value conf) else (k, v))
         conf.henv
     ;
+    if conf.user <> "" then
+      let wpf =
+        try List.assoc "wizard_passwd_file" conf.base_env with
+        [ Not_found -> "" ]
+      in
+      if wpf <> "" then
+        let fname = adm_file (conf.bname ^ "_u.txt") in
+        update_wf_trace conf fname
+      else ()
+    else ();
   }
 ;
 
-(* Deprecated *)
+(* List selection bullets *)
 
-value afficher_personne conf base p =
-  Wserver.wprint "%s" (person_text conf base p)
+value bullet_sel_txt = "<tt>o</tt>";
+value bullet_unsel_txt = "<tt>+</tt>";
+value bullet_nosel_txt = "<tt>o</tt>";
+value print_selection_bullet conf =
+  fun
+  [ Some (txt, sel) ->
+      let req =
+        List.fold_left
+          (fun req (k, v) ->
+             if not sel && k = "u" && v = txt then req
+             else
+               let s = k ^ "=" ^ v in
+               if req = "" then s else req ^ ";" ^ s)
+          "" conf.env
+      in
+      do {
+        Wserver.wprint "<a name=%s>" txt;
+        Wserver.wprint "<a href=\"%s%s%s%s\">" (commd conf) req
+          (if sel then ";u=" ^ txt else "")
+          (if sel || List.mem_assoc "u" conf.env then "#" ^ txt else "");
+        Wserver.wprint "%s"
+          (if sel then bullet_sel_txt else bullet_unsel_txt);
+        Wserver.wprint "</a></a>\n";
+      }
+  | None -> Wserver.wprint "%s\n" bullet_nosel_txt ]
 ;
 
-value afficher_prenom_de_personne conf base p =
-  Wserver.wprint "%s" (person_text_without_surname conf base p)
-;
-
-value afficher_prenom_de_personne_referencee conf base p =
-  Wserver.wprint "%s"
-    (reference conf base p (person_text_without_surname conf base p))
-;
-
-value afficher_personne_referencee conf base p =
-  Wserver.wprint "\n%s" (reference conf base p (person_text conf base p))
-;
-
-value afficher_personne_titre conf base p =
-  Wserver.wprint "%s" (person_title_text conf base p)
-;
-
-value afficher_personne_titre_referencee conf base p =
-  Wserver.wprint "\n%s" (referenced_person_title_text conf base p)
+value unselected_bullets conf =
+  List.fold_left
+    (fun sl (k, v) ->
+       try
+         if k = "u" then [int_of_string v :: sl]
+         else sl
+       with
+       [ Failure _ -> sl ])
+    [] conf.env
 ;
