@@ -1,4 +1,4 @@
-(* $Id: wserver.ml,v 4.17 2002/03/08 15:18:26 ddr Exp $ *)
+(* $Id: wserver.ml,v 4.19 2002/12/23 13:38:37 ddr Exp $ *)
 (* Copyright (c) 2002 INRIA *)
 
 value sock_in = ref "wserver.sin";
@@ -638,7 +638,9 @@ value f addr_opt port tmout max_clients g =
         flush stderr;
         while True do {
           try accept_connection tmout max_clients g s with
-          [ Unix.Unix_error (Unix.ECONNRESET | Unix.EBADF) "accept" _ -> ()
+          [ Unix.Unix_error Unix.ECONNRESET "accept" _ -> ()
+          | Unix.Unix_error (Unix.EBADF | Unix.ENOTSOCK) "accept" _ as x ->
+              (* oops! *) raise x
           | exc -> print_err_exc exc ];
           try wflush () with [ Sys_error _ -> () ];
           try flush stdout with [ Sys_error _ -> () ];
